-- NOTE: The database structure must also be maintained in the
-- /maintenance/libraries/max/Dal/table_core.sql file.

-- Note: ENUM() definitions in tables can NOT have a space after
-- the separating comma, or the phpAdsNew table creation code 
-- will fail silently! Similarly for multi-column PRIMARY KEYs!

CREATE TABLE max_acls (
  bannerid mediumint(9) NOT NULL DEFAULT '0',
  logical set('and','or') NOT NULL DEFAULT '',
  type VARCHAR(16) NOT NULL DEFAULT '',
  comparison char(2) NOT NULL DEFAULT '==',
  data text NOT NULL,
  executionorder int(10) unsigned NOT NULL DEFAULT '0',
  UNIQUE KEY bannerid_executionorder (bannerid,executionorder),
  KEY bannerid (bannerid)
);

CREATE TABLE max_ad_category_assoc (
  ad_category_assoc_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  category_id INTEGER UNSIGNED NOT NULL,
  ad_id INTEGER UNSIGNED NOT NULL,
  PRIMARY KEY(ad_category_assoc_id)
);

CREATE TABLE max_ad_zone_assoc (
  ad_zone_assoc_id mediumint(9) NOT NULL AUTO_INCREMENT,
  zone_id mediumint(9) default NULL,
  ad_id mediumint(9) default NULL,
  priority int(11) NOT NULL DEFAULT 0,
  link_type smallint(6) NOT NULL DEFAULT 1,
  PRIMARY KEY  (ad_zone_assoc_id),
  INDEX zone_id (zone_id),
  INDEX ad_id (ad_id)
);

CREATE TABLE max_affiliates (
  affiliateid mediumint(9) NOT NULL AUTO_INCREMENT,
  agencyid mediumint(9) NOT NULL DEFAULT '0',
  name VARCHAR(255) NOT NULL DEFAULT '',
  mnemonic VARCHAR(5) NOT NULL DEFAULT '',
  contact VARCHAR(255) DEFAULT NULL,
  email VARCHAR(64) NOT NULL DEFAULT '',
  website VARCHAR(255) DEFAULT NULL,
  username VARCHAR(64) DEFAULT NULL,
  password VARCHAR(64) DEFAULT NULL,
  permissions mediumint(9) DEFAULT NULL,
  language VARCHAR(64) DEFAULT NULL,
  publiczones enum('t','f') NOT NULL DEFAULT 'f',
  PRIMARY KEY(affiliateid)
);

CREATE TABLE max_agency (
  agencyid mediumint(9) NOT NULL AUTO_INCREMENT,
  name VARCHAR(255) NOT NULL DEFAULT '',
  contact VARCHAR(255) DEFAULT NULL,
  email VARCHAR(64) NOT NULL DEFAULT '',
  username VARCHAR(64) DEFAULT NULL,
  password VARCHAR(64) DEFAULT NULL,
  permissions mediumint(9) DEFAULT NULL,
  language VARCHAR(64) DEFAULT NULL,
  PRIMARY KEY(agencyid)
);

CREATE TABLE max_application_variable (
  name VARCHAR(255) NOT NULL DEFAULT '',
  value VARCHAR(255) NOT NULL DEFAULT ''
);

CREATE TABLE max_banners (
  bannerid mediumint(9) NOT NULL AUTO_INCREMENT,
  campaignid mediumint(9) NOT NULL DEFAULT '0',
  active enum('t','f') NOT NULL DEFAULT 't',
  contenttype enum('gif','jpeg','png','html','swf','dcr','rpm','mov','txt') NOT NULL DEFAULT 'gif',
  pluginversion mediumint(9) NOT NULL DEFAULT '0',
  storagetype enum('sql','web','url','html','network','txt') NOT NULL DEFAULT 'sql',
  filename VARCHAR(255) NOT NULL DEFAULT '',
  imageurl VARCHAR(255) NOT NULL DEFAULT '',
  htmltemplate text NOT NULL,
  htmlcache text NOT NULL,
  width smallint(6) NOT NULL DEFAULT '0',
  height smallint(6) NOT NULL DEFAULT '0',
  weight tinyint(4) NOT NULL DEFAULT '1',
  seq tinyint(4) NOT NULL DEFAULT '0',
  target VARCHAR(16) NOT NULL DEFAULT '',
  url text NOT NULL DEFAULT '',
  alt VARCHAR(255) NOT NULL DEFAULT '',
  status VARCHAR(255) NOT NULL DEFAULT '',
  bannertext text NOT NULL,
  description VARCHAR(255) NOT NULL DEFAULT '',
  autohtml enum('t','f') NOT NULL DEFAULT 't',
  adserver VARCHAR(50) NOT NULL DEFAULT '',
  block int(11) NOT NULL DEFAULT '0',
  capping int(11) NOT NULL DEFAULT '0',
  session_capping int(11) NOT NULL DEFAULT '0',
  compiledlimitation text NOT NULL,
  append text NOT NULL,
  appendtype tinyint(4) NOT NULL DEFAULT '0',
  bannertype tinyint(4) NOT NULL DEFAULT '0',
  alt_filename VARCHAR(255) NOT NULL DEFAULT '',
  alt_imageurl VARCHAR(255) NOT NULL DEFAULT '',
  alt_contenttype enum('gif','jpeg','png') NOT NULL DEFAULT 'gif',
  PRIMARY KEY(bannerid),
  KEY campaignid (campaignid)
);

CREATE TABLE max_cache (
  cacheid VARCHAR(255) NOT NULL DEFAULT '',
  content text NOT NULL,
  PRIMARY KEY(cacheid)
);

CREATE TABLE max_campaigns (
  campaignid mediumint(9) NOT NULL AUTO_INCREMENT,
  campaignname VARCHAR(255) NOT NULL DEFAULT '',
  clientid mediumint(9) NOT NULL DEFAULT '0',
  views int(11) DEFAULT '-1',
  clicks int(11) DEFAULT '-1',
  conversions int(11) DEFAULT '-1',
  expire date DEFAULT '0000-00-00',
  activate date DEFAULT '0000-00-00',
  active enum('t','f') NOT NULL DEFAULT 't',
  priority enum('h','m','l') NOT NULL DEFAULT 'l',
  weight tinyint(4) NOT NULL DEFAULT '1',
  target int(11) NOT NULL DEFAULT '0',
  optimise enum('t','f') NOT NULL DEFAULT 'f',
  anonymous enum('t','f') NOT NULL DEFAULT 'f',
  PRIMARY KEY(campaignid)
);

CREATE TABLE max_campaigns_trackers (
  campaign_trackerid mediumint(9) NOT NULL AUTO_INCREMENT,
  campaignid mediumint(9) NOT NULL DEFAULT '0',
  trackerid mediumint(9) NOT NULL DEFAULT '0',
  logstats enum('y','n') NOT NULL DEFAULT 'y',
  viewwindow mediumint(9) NOT NULL DEFAULT '0',
  clickwindow mediumint(9) NOT NULL DEFAULT '0',
  PRIMARY KEY(campaign_trackerid),
  KEY campaignid (campaignid),
  KEY trackerid (trackerid)
);

CREATE TABLE max_category (
  category_id INTEGER UNSIGNED NOT NULL AUTO_INCREMENT,
  name VARCHAR(255) NULL,
  PRIMARY KEY(category_id)
);

CREATE TABLE max_clients (
  clientid mediumint(9) NOT NULL AUTO_INCREMENT,
  agencyid mediumint(9) NOT NULL DEFAULT '0',
  clientname VARCHAR(255) NOT NULL DEFAULT '',
  contact VARCHAR(255) DEFAULT NULL,
  email VARCHAR(64) NOT NULL DEFAULT '',
  clientusername VARCHAR(64) NOT NULL DEFAULT '',
  clientpassword VARCHAR(64) NOT NULL DEFAULT '',
  permissions mediumint(9) DEFAULT NULL,
  language VARCHAR(64) DEFAULT NULL,
  report enum('t','f') NOT NULL DEFAULT 't',
  reportinterval mediumint(9) NOT NULL DEFAULT '7',
  reportlastdate date NOT NULL DEFAULT '0000-00-00',
  reportdeactivate enum('t','f') NOT NULL DEFAULT 't',
  PRIMARY KEY(clientid)
);

CREATE TABLE max_config (
  agencyid mediumint(9) NOT NULL DEFAULT '0',
  config_version decimal(7,3) NOT NULL DEFAULT '0.000',
  table_border_color VARCHAR(7) DEFAULT '#000099',
  table_back_color VARCHAR(7) DEFAULT '#CCCCCC',
  table_back_color_alternative VARCHAR(7) DEFAULT '#F7F7F7',
  main_back_color VARCHAR(7) DEFAULT '#FFFFFF',
  my_header VARCHAR(255) DEFAULT NULL,
  my_footer VARCHAR(255) DEFAULT NULL,
  language VARCHAR(32) DEFAULT 'english',
  name VARCHAR(32) DEFAULT NULL,
  company_name VARCHAR(255) DEFAULT 'mysite.com',
  override_gd_imageformat VARCHAR(4) DEFAULT NULL,
  begin_of_week tinyint(2) DEFAULT '1',
  percentage_decimals tinyint(2) DEFAULT '2',
  type_sql_allow enum('t','f') DEFAULT 't',
  type_url_allow enum('t','f') DEFAULT 't',
  type_web_allow enum('t','f') DEFAULT 'f',
  type_html_allow enum('t','f') DEFAULT 't',
  type_txt_allow enum('t','f') DEFAULT 't',
  type_web_mode tinyint(2) DEFAULT '0',
  type_web_dir VARCHAR(255) DEFAULT NULL,
  type_web_ftp VARCHAR(255) DEFAULT NULL,
  type_web_url VARCHAR(255) DEFAULT NULL,
  admin VARCHAR(64) DEFAULT 'phpadsuser',
  admin_pw VARCHAR(64) DEFAULT 'phpadspass',
  admin_fullname VARCHAR(255) DEFAULT 'Your Name',
  admin_email VARCHAR(64) DEFAULT 'your@email.com',
  warn_admin enum('t','f') DEFAULT 't',
  warn_agency enum('t','f') DEFAULT 't',
  warn_client enum('t','f') DEFAULT 't',
  warn_limit mediumint(9) NOT NULL DEFAULT '0',
  admin_email_headers VARCHAR(64) DEFAULT NULL,
  admin_novice enum('t','f') DEFAULT 't',
  default_banner_weight tinyint(4) DEFAULT '1',
  default_campaign_weight tinyint(4) DEFAULT '1',
  client_welcome enum('t','f') DEFAULT 't',
  client_welcome_msg text,
  content_gzip_compression enum('t','f') DEFAULT 'f',
  userlog_email enum('t','f') DEFAULT 't',
  userlog_priority enum('t','f') DEFAULT 't',
  userlog_autoclean enum('t','f') DEFAULT 't',
  gui_show_campaign_info enum('t','f') DEFAULT 't',
  gui_show_campaign_preview enum('t','f') DEFAULT 'f',
  gui_campaign_anonymous enum('t','f') DEFAULT 'f',
  gui_show_banner_info enum('t','f') DEFAULT 't',
  gui_show_banner_preview enum('t','f') DEFAULT 't',
  gui_show_banner_html enum('t','f') DEFAULT 'f',
  gui_show_matching enum('t','f') DEFAULT 't',
  gui_show_parents enum('t','f') DEFAULT 'f',
  gui_hide_inactive enum('t','f') DEFAULT 'f',
  gui_link_compact_limit INTEGER DEFAULT '50',
  qmail_patch enum('t','f') DEFAULT 'f',
  updates_frequency tinyint(2) DEFAULT '7',
  updates_timestamp int(11) DEFAULT '0',
  updates_last_seen decimal(7,3) DEFAULT '0.000',
  allow_invocation_plain enum('t','f') DEFAULT 'f',
  allow_invocation_plain_nocookies enum('t','f') DEFAULT 't',
  allow_invocation_js enum('t','f') DEFAULT 't',
  allow_invocation_frame enum('t','f') DEFAULT 'f',
  allow_invocation_xmlrpc enum('t','f') DEFAULT 'f',
  allow_invocation_local enum('t','f') DEFAULT 't',
  allow_invocation_interstitial enum('t','f') DEFAULT 't',
  allow_invocation_popup enum('t','f') DEFAULT 't',
  auto_clean_tables enum('t','f') DEFAULT 'f',
  auto_clean_tables_interval tinyint(2) DEFAULT '5',
  auto_clean_userlog enum('t','f') DEFAULT 'f',
  auto_clean_userlog_interval tinyint(2) DEFAULT '5',
  auto_clean_tables_vacuum enum('t','f') DEFAULT 't',
  autotarget_factor float DEFAULT '-1',
  maintenance_timestamp int(11) DEFAULT '0',
  compact_stats enum('t','f') DEFAULT 't',
  statslastday date NOT NULL DEFAULT '0000-00-00',
  statslasthour tinyint(4) NOT NULL DEFAULT '0',
  PRIMARY KEY(agencyid)
);

CREATE TABLE max_data_intermediate_ad (
  data_intermediate_keyword_id BIGINT NOT NULL AUTO_INCREMENT,
  day DATE NOT NULL,
  hour INTEGER UNSIGNED NOT NULL,
  operation_interval INTEGER UNSIGNED NOT NULL,
  operation_interval_id INTEGER UNSIGNED NOT NULL,
  interval_start DATETIME NOT NULL,
  interval_end DATETIME NOT NULL,
  ad_id INTEGER UNSIGNED NOT NULL,
  creative_id INTEGER UNSIGNED NOT NULL,
  zone_id INTEGER UNSIGNED NOT NULL,
  requests INTEGER UNSIGNED NOT NULL DEFAULT 0,
  impressions INTEGER UNSIGNED NOT NULL DEFAULT 0,
  clicks INTEGER UNSIGNED NOT NULL DEFAULT 0,
  conversions INTEGER UNSIGNED NOT NULL DEFAULT 0,
  total_basket_value DECIMAL(10,4) NOT NULL DEFAULT 0,
  PRIMARY KEY(data_intermediate_keyword_id),
  INDEX data_intermediate_ad_day(day),
  INDEX data_intermediate_ad_operation_interval_id(operation_interval_id),
  INDEX data_intermediate_ad_ad_id(ad_id),
  INDEX data_intermediate_ad_zone_id(zone_id)
);

CREATE TABLE max_data_intermediate_ad_connection (
  data_intermediate_ad_connection_id BIGINT NOT NULL AUTO_INCREMENT,
  server_raw_ip VARCHAR(16) NOT NULL,
  server_raw_tracker_impression_id BIGINT NOT NULL,
  viewer_id VARCHAR(32) NULL,
  viewer_session_id VARCHAR(32) NULL,
  tracker_date_time DATETIME NOT NULL,
  connection_date_time DATETIME NULL,
  tracker_id INTEGER UNSIGNED NOT NULL,
  ad_id INTEGER UNSIGNED NOT NULL,
  creative_id INTEGER UNSIGNED NOT NULL,
  zone_id INTEGER UNSIGNED NOT NULL,
  tracker_channel VARCHAR(51) NULL,
  connection_channel VARCHAR(51) NULL,
  tracker_language VARCHAR(13) NULL,
  connection_language VARCHAR(13) NULL,
  tracker_ip_address VARCHAR(16) NULL,
  connection_ip_address VARCHAR(16) NULL,
  tracker_host_name TEXT NULL,
  connection_host_name TEXT NULL,
  tracker_country CHAR(2) NULL,
  connection_country CHAR(2) NULL,
  tracker_https INTEGER UNSIGNED NULL,
  connection_https INTEGER UNSIGNED NULL,
  tracker_domain VARCHAR(255) NULL,
  connection_domain VARCHAR(255) NULL,
  tracker_page VARCHAR(255) NULL,
  connection_page VARCHAR(255) NULL,
  tracker_query VARCHAR(255) NULL,
  connection_query VARCHAR(255) NULL,
  tracker_referer VARCHAR(255) NULL,
  connection_referer VARCHAR(255) NULL,
  tracker_search_term VARCHAR(255) NULL,
  connection_search_term VARCHAR(255) NULL,
  tracker_user_agent VARCHAR(255) NULL,
  connection_user_agent VARCHAR(255) NULL,
  tracker_os VARCHAR(32) NULL,
  connection_os VARCHAR(32) NULL,
  tracker_browser VARCHAR(32) NULL,
  connection_browser VARCHAR(32) NULL,
  connection_type INTEGER UNSIGNED NULL,
  connection_window INTEGER UNSIGNED NULL,
  conversion enum('y','n') NOT NULL,
  PRIMARY KEY(data_intermediate_ad_connection_id),
  INDEX data_intermediate_connection_tracker_date_time(tracker_date_time),
  INDEX data_intermediate_ad_connection_tracker_date_time(tracker_date_time),
  INDEX data_intermediate_ad_connection_tracker_id(tracker_id),
  INDEX data_intermediate_ad_connection_ad_id(ad_id),
  INDEX data_intermediate_ad_connection_zone_id(zone_id)
);

CREATE TABLE max_data_intermediate_ad_variable_value (
  data_intermediate_ad_variable_value_id BIGINT NOT NULL AUTO_INCREMENT,
  data_intermediate_ad_connection_id BIGINT NOT NULL,
  tracker_variable_id INTEGER NOT NULL,
  value VARCHAR(50) NULL,
  PRIMARY KEY(data_intermediate_ad_variable_value_id)
);

-- SPLIT TABLE data_raw_ad_click

CREATE TABLE max_data_raw_ad_click (
  viewer_id VARCHAR(32) NULL,
  viewer_session_id VARCHAR(32) NULL,
  date_time DATETIME NOT NULL,
  ad_id INTEGER UNSIGNED NOT NULL,
  creative_id INTEGER UNSIGNED NOT NULL,
  zone_id INTEGER UNSIGNED NOT NULL,
  channel VARCHAR(51) NULL,
  language VARCHAR(32) NULL,
  ip_address VARCHAR(16) NULL,
  host_name TEXT NULL,
  country CHAR(2) NULL,
  https BOOL NULL,
  domain VARCHAR(255) NULL,
  page VARCHAR(255) NULL,
  query VARCHAR(255) NULL,
  referer VARCHAR(255) NULL,
  search_term VARCHAR(255) NULL,
  user_agent VARCHAR(255) NULL,
  os VARCHAR(32) NULL,
  browser VARCHAR(32) NULL,
  max_https BOOL NULL,
  INDEX data_raw_ad_click_viewer_id(viewer_id),
  INDEX data_raw_ad_click_date_time(date_time),
  INDEX data_raw_ad_click_ad_id(ad_id)
);

-- SPLIT TABLE data_raw_ad_impression

CREATE TABLE max_data_raw_ad_impression (
  viewer_id VARCHAR(32) NULL,
  viewer_session_id VARCHAR(32) NULL,
  date_time DATETIME NOT NULL,
  ad_id INTEGER UNSIGNED NOT NULL,
  creative_id INTEGER UNSIGNED NOT NULL,
  zone_id INTEGER UNSIGNED NOT NULL,
  channel VARCHAR(51) NULL,
  language VARCHAR(32) NULL,
  ip_address VARCHAR(16) NULL,
  host_name TEXT NULL,
  country CHAR(2) NULL,
  https BOOL NULL,
  domain VARCHAR(255) NULL,
  page VARCHAR(255) NULL,
  query VARCHAR(255) NULL,
  referer VARCHAR(255) NULL,
  search_term VARCHAR(255) NULL,
  user_agent VARCHAR(255) NULL,
  os VARCHAR(32) NULL,
  browser VARCHAR(32) NULL,
  max_https BOOL NULL,
  INDEX data_raw_ad_impression_viewer_id(viewer_id),
  INDEX data_raw_ad_impression_date_time(date_time),
  INDEX data_raw_ad_impression_ad_id(ad_id)
);

-- SPLIT TABLE data_raw_ad_request

CREATE TABLE max_data_raw_ad_request (
  viewer_id VARCHAR(32) NULL,
  viewer_session_id VARCHAR(32) NULL,
  date_time DATETIME NOT NULL,
  ad_id INTEGER UNSIGNED NOT NULL,
  creative_id INTEGER UNSIGNED NOT NULL,
  zone_id INTEGER UNSIGNED NOT NULL,
  channel VARCHAR(51) NULL,
  language VARCHAR(32) NULL,
  ip_address VARCHAR(16) NULL,
  host_name TEXT NULL,
  country CHAR(2) NULL,
  https BOOL NULL,
  domain VARCHAR(255) NULL,
  page VARCHAR(255) NULL,
  query VARCHAR(255) NULL,
  referer VARCHAR(255) NULL,
  search_term VARCHAR(255) NULL,
  user_agent VARCHAR(255) NULL,
  os VARCHAR(32) NULL,
  browser VARCHAR(32) NULL,
  max_https BOOL NULL,
  INDEX data_raw_ad_request_viewer_id(viewer_id),
  INDEX data_raw_ad_request_date_time(date_time),
  INDEX data_raw_ad_request_ad_id(ad_id)
);

-- SPLIT TABLE data_raw_tracker_click

CREATE TABLE max_data_raw_tracker_click (
  viewer_id VARCHAR(32) NULL,
  viewer_session_id VARCHAR(32) NOT NULL,
  date_time DATETIME NOT NULL,
  tracker_id INTEGER UNSIGNED NOT NULL,
  channel VARCHAR(51) NULL,
  language VARCHAR(32) NULL,
  ip_address VARCHAR(16) NULL,
  host_name TEXT NULL,
  country CHAR(2) NULL,
  https BOOL NULL,
  domain VARCHAR(255) NULL,
  page VARCHAR(255) NULL,
  query VARCHAR(255) NULL,
  referer VARCHAR(255) NULL,
  search_term VARCHAR(255) NULL,
  user_agent VARCHAR(255) NULL,
  os VARCHAR(32) NULL,
  browser VARCHAR(32) NULL,
  max_https BOOL NULL,
  INDEX data_raw_tracker_click_viewer_id(viewer_id),
  INDEX data_raw_tracker_click_date_time(date_time)
);

-- SPLIT TABLE data_raw_tracker_impression

CREATE TABLE max_data_raw_tracker_impression (
  server_raw_tracker_impression_id BIGINT NOT NULL AUTO_INCREMENT,
  server_raw_ip VARCHAR(16) NOT NULL,
  viewer_id VARCHAR(32) NOT NULL,
  viewer_session_id VARCHAR(32) NULL,
  date_time DATETIME NOT NULL,
  tracker_id INTEGER UNSIGNED NOT NULL,
  channel VARCHAR(51) NULL,
  language VARCHAR(32) NULL,
  ip_address VARCHAR(16) NULL,
  host_name TEXT NULL,
  country CHAR(2) NULL,
  https INTEGER UNSIGNED NULL,
  domain VARCHAR(255) NULL,
  page VARCHAR(255) NULL,
  query VARCHAR(255) NULL,
  referer VARCHAR(255) NULL,
  search_term VARCHAR(255) NULL,
  user_agent VARCHAR(255) NULL,
  os VARCHAR(32) NULL,
  browser VARCHAR(32) NULL,
  max_https INTEGER UNSIGNED NULL,
  PRIMARY KEY(server_raw_tracker_impression_id,server_raw_ip),
  INDEX data_raw_tracker_impression_viewer_id(viewer_id),
  INDEX data_raw_tracker_impression_date_time(date_time)
);

-- SPLIT TABLE data_raw_tracker_variable_value

CREATE TABLE max_data_raw_tracker_variable_value (
  server_raw_tracker_impression_id BIGINT NOT NULL,
  server_raw_ip VARCHAR(16) NOT NULL,
  tracker_variable_id INTEGER NOT NULL,
  date_time DATETIME NULL,
  value VARCHAR(50) NULL,
  PRIMARY KEY(server_raw_tracker_impression_id,server_raw_ip,tracker_variable_id)
);

CREATE TABLE max_data_summary_ad_hourly (
  data_summary_ad_hourly_id BIGINT NOT NULL AUTO_INCREMENT,
  day DATE NOT NULL,
  hour INTEGER UNSIGNED NOT NULL,
  ad_id INTEGER UNSIGNED NOT NULL,
  creative_id INTEGER UNSIGNED NOT NULL,
  zone_id INTEGER UNSIGNED NOT NULL,
  requests INTEGER UNSIGNED NOT NULL DEFAULT 0,
  impressions INTEGER UNSIGNED NOT NULL DEFAULT 0,
  clicks INTEGER UNSIGNED NOT NULL DEFAULT 0,
  conversions INTEGER UNSIGNED NOT NULL DEFAULT 0,
  total_basket_value DECIMAL(10,4) NULL,
  PRIMARY KEY(data_summary_ad_hourly_id),
  INDEX data_summary_ad_hourly_day(day),
  INDEX data_summary_ad_hourly_hour(hour),
  INDEX data_summary_ad_hourly_ad_id(ad_id),
  INDEX data_summary_ad_hourly_zone_id(zone_id)
);

CREATE TABLE max_data_summary_zone_impression_history (
  data_summary_zone_impression_history_id BIGINT NOT NULL AUTO_INCREMENT,
  operation_interval INTEGER UNSIGNED NOT NULL,
  operation_interval_id INTEGER UNSIGNED NOT NULL,
  interval_start DATETIME NOT NULL,
  interval_end DATETIME NOT NULL,
  zone_id INTEGER UNSIGNED NOT NULL,
  forecast_impressions INTEGER UNSIGNED NOT NULL DEFAULT 1,
  actual_impressions INTEGER UNSIGNED NULL,
  PRIMARY KEY(data_summary_zone_impression_history_id),
  INDEX data_summary_zone_impression_history_operation_interval_id(operation_interval_id)
);

CREATE TABLE max_images (
  filename VARCHAR(128) NOT NULL DEFAULT '',
  contents mediumblob NOT NULL,
  t_stamp timestamp(14) NOT NULL,
  PRIMARY KEY(filename)
);

CREATE TABLE max_log_maintenance (
  log_maintenance_id INT NOT NULL AUTO_INCREMENT,
  start_run DATETIME NULL,
  end_run DATETIME NULL,
  duration INT NULL,
  PRIMARY KEY(log_maintenance_id)
);

CREATE TABLE max_log_maintenance_statistics (
  log_maintenance_statistics_id INT NOT NULL AUTO_INCREMENT,
  start_run DATETIME NOT NULL,
  end_run DATETIME NOT NULL,
  duration INT NOT NULL,
  adserver_run_type INT(2) NULL,
  search_run_type INT(2) NULL,
  tracker_run_type INT(2) NULL,
  updated_to DATETIME NULL,
  PRIMARY KEY(log_maintenance_statistics_id)
);

CREATE TABLE max_placement_zone_assoc (
  placement_zone_assoc_id mediumint(9) NOT NULL AUTO_INCREMENT,
  zone_id mediumint(9) default NULL,
  placement_id mediumint(9) default NULL,
  PRIMARY KEY  (placement_zone_assoc_id),
  INDEX zone_id (zone_id),
  INDEX placement_id (placement_id)
);

CREATE TABLE max_session (
  sessionid VARCHAR(32) NOT NULL DEFAULT '',
  sessiondata text NOT NULL,
  lastused timestamp(14) NOT NULL,
  PRIMARY KEY(sessionid)
);

CREATE TABLE max_targetstats (
  day date NOT NULL DEFAULT '0000-00-00',
  campaignid mediumint(9) NOT NULL DEFAULT '0',
  target int(11) NOT NULL DEFAULT '0',
  views int(11) NOT NULL DEFAULT '0',
  modified tinyint(4) NOT NULL DEFAULT '0'
);

CREATE TABLE max_trackers (
  trackerid mediumint(9) NOT NULL AUTO_INCREMENT,
  trackername VARCHAR(255) NOT NULL DEFAULT '',
  description VARCHAR(255) NOT NULL DEFAULT '',
  clientid mediumint(9) NOT NULL DEFAULT '0',
  viewwindow mediumint(9) NOT NULL DEFAULT '0',
  clickwindow mediumint(9) NOT NULL DEFAULT '0',
  blockwindow mediumint(9) NOT NULL DEFAULT '0',
  PRIMARY KEY(trackerid)
);

CREATE TABLE max_userlog (
  userlogid mediumint(9) NOT NULL AUTO_INCREMENT,
  timestamp int(11) NOT NULL DEFAULT '0',
  usertype tinyint(4) NOT NULL DEFAULT '0',
  userid mediumint(9) NOT NULL DEFAULT '0',
  action mediumint(9) NOT NULL DEFAULT '0',
  object mediumint(9) DEFAULT NULL,
  details MEDIUMTEXT,
  PRIMARY KEY(userlogid)
);

CREATE TABLE max_variables (
  variableid mediumint(9) unsigned NOT NULL AUTO_INCREMENT,
  trackerid VARCHAR(32) NOT NULL DEFAULT '',
  name VARCHAR(250) NOT NULL DEFAULT '',
  description VARCHAR(250) DEFAULT NULL,
  datatype enum('int','string') NOT NULL DEFAULT 'int',
  is_basket_value INTEGER NOT NULL DEFAULT 0,
  PRIMARY KEY(variableid)
);

CREATE TABLE max_zones (
  zoneid mediumint(9) NOT NULL AUTO_INCREMENT,
  affiliateid mediumint(9) DEFAULT NULL,
  zonename VARCHAR(245) NOT NULL DEFAULT '',
  description VARCHAR(255) NOT NULL DEFAULT '',
  delivery smallint(6) NOT NULL DEFAULT '0',
  zonetype smallint(6) NOT NULL DEFAULT '0',
  category text NOT NULL,
  width smallint(6) NOT NULL DEFAULT '0',
  height smallint(6) NOT NULL DEFAULT '0',
  ad_selection TEXT NOT NULL DEFAULT '',
  chain text NOT NULL,
  prepend text NOT NULL,
  append text NOT NULL,
  appendtype tinyint(4) NOT NULL DEFAULT '0',
  forceappend enum('t','f') DEFAULT 'f',
  PRIMARY KEY(zoneid),
  KEY zonenameid(zonename,zoneid)
);