<?php

/*
+---------------------------------------------------------------------------+
| Max Media Manager v0.2                                                    |
| =================                                                         |
|                                                                           |
| Copyright (c) 2003-2005 Awarez Ltd.                                       |
| For contact details, see: http://www.awarez.net/                          |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: StatisticsTracker.php 1239 2005-01-17 17:39:11Z andrew $
*/

/**
 * @package    MaxDal
 * @subpackage Statistics
 * @author     Andrew Hill <andrew@awarez.net>
 */

require_once maintenancePath . '/maintenance-common.php';
require_once maintenancePath . '/libraries/max/Maintenance.php';
require_once maintenancePath . '/libraries/max/Dal/StatisticsCommon.php';
require_once maintenancePath . '/libraries/pear/Date.php';
 
/**
 * The data access layer code for summarising raw data into statistics, for 
 * the Tracker module.
 */
class Dal_Statistics_Tracker extends Dal_Statistics_Common
{

    /**
     * The constructor method.
     *
     * @uses Dal_Statistics_Common::Dal_Statistics_Common()
     */
    function Dal_Statistics_Tracker()
    {
        parent::Dal_Statistics_Common();
    }
    
    /**
     * The singleton method to create or return a single instance of the class.
     *
     * @static
     * @return Dal_Statistics_Tracker The returned Dal_Statistics_Tracker object.
     */
    function &singleton() {
        static $instance;
        if (!isset($instance)) {
            $instance = new Dal_Statistics_Tracker();
        }
        return $instance;
    }
    
    /**
     * A method to find the last time that maintenance statistics was run.
     *
     * @param integer $type The update type that occurred - that is, 0 if
     *                      the update was done on the basis of the 
     *                      operation interval, or 1 if the update was
     *                      done on the basis of the hour.
     * @param Date $now An optional Date, used to specify the "current time", and
     *                  to limit the method to only look for past maintenance
     *                  statistics runs before this date. Normally only used
     *                  to assist with re-generation of statistics in the event
     *                  of faulty raw tables.
     * @return Date A Date representing the date up to which the statistics
     *              have been summarised, for the specified update type, or
     *              the appropriate date based on raw data if maintenance
     *              statistics has never been run for the Max module before.
     *              Returns null if no raw data is available.
     */
    function getMaintenanceStatisticsLastRunInfo($type, $now = null)
    {
        $table = $this->conf['table']['data_raw_tracker_impression'];
        return $this->_getMaintenanceStatisticsLastRunInfo($type, $table, $now);
    }
    
    /**
     * A private function to do the job of
     * {@link Dal_Statistics_Tracker::getMaintenanceStatisticsLastRunInfo()}, but with an
     * extra parameter to specify the raw table to look in, in the case of
     * maintenance statistics not having been run before.
     *
     * @private
     * @param integer $type The update type that occurred - that is, 0 if
     *                      the update was done on the basis of the 
     *                      operation interval, or 1 if the update was
     *                      done on the basis of the hour.
     * @param string $rawTable The raw table to use in case of no previous run.
     * @param Date $now An optional Date, used to specify the "current time", and
     *                  to limit the method to only look for past maintenance
     *                  statistics runs before this date. Normally only used
     *                  to assist with re-generation of statistics in the event
     *                  of faulty raw tables.
     * @return Date A Date representing the date up to which the statistics
     *              have been summarised, for the specified update type, or
     *              the appropriate date based on raw data if maintenance
     *              statistics has never been run for the Max module before.
     *              Returns null if no raw data is available.
     */
    function _getMaintenanceStatisticsLastRunInfo($type, $rawTable, $now = null) {
        if ($type == 0) {
            $whereClause = 'WHERE (lms.tracker_run_type = 0 OR lms.tracker_run_type = 2)';
        } else if ($type == 1) {
            $whereClause = 'WHERE (lms.tracker_run_type = 1 OR lms.tracker_run_type = 2)';
        } else {
            debug('Invalid update type value ' . $type . ': Must be 0 or 1', PEAR_LOG_ERROR);
            debug('Aborting script execution', PEAR_LOG_ERROR);
            exit();
        }
        if (!is_null($now)) {
            // Limit to past maintenance statistics runs before this Date
            $whereClause .= ' AND updated_to < ' . "'" . $now->format('%Y-%m-%d %H:%M:%S') . "'";
        }
        $query = "
            SELECT
                lms.updated_to AS date
            FROM 
                {$this->conf['table']['log_maintenance_statistics']} AS lms
            $whereClause
            ORDER BY date DESC
            LIMIT 1";
        debug('Getting the details of when maintenance statistics last ran for the Tracker module',
              PEAR_LOG_DEBUG);
        $this->execute($query, $result);
        $row = $this->fetchResultAsArray($result);
        if ($row) {
            $date = new Date($row['date']);
            return $date;
        } else {
            // Maintenance statistics has never been run - query the raw data
            $query = "
                SELECT
                    raw.date_time AS date
                FROM
                    $rawTable AS raw
                ORDER BY date ASC
                LIMIT 1";
            debug('Getting the details of when the first tracker click is for the Tracker module',
                  PEAR_LOG_DEBUG);
            $errors = array(1146);   // Permit the table does not exist error
            $errorID = $this->executeIgnoreErrors($query, $result, $errors);
            if ($errorID == 0) {
                $row = $this->fetchResultAsArray($result);
                if ($row) {
                    // Convert the click time into the end of the previous operation interval or hour
                    $date = new Date($row['date']);
                    if ($type == 0) {
                        list($date, $_) = Maintenance::convertDateToOperationIntervalStartAndEndDates($date);
                        $date->subtractSeconds(1);
                        return $date;
                    } else {
                        $date = new Date($date->format('%Y-%m-%d %H:00:00'));
                        $date->subtractSeconds(1);
                        return $date;
                    }
                }
            }
            // No raw data was found
            return null;
        }
    }
    
    /**
     * A method to delete old (ie. summarised) raw data.
     *
     * @param Date $summarisedTo The date/time up to which data have been summarised (i.e. data up
     *                           to and including this date (minus any compact_stats_grace window)
     *                           will be deleted).
     * @return integer The number of rows deleted.
     */
    function deleteOldData($summarisedTo)
    {
        $deleteDate = $summarisedTo;
        if ($this->conf['maintenance']['compact_stats_grace'] > 0) {
            $deleteDate->subtractSeconds((int) $this->conf['maintenance']['compact_stats_grace']);
        }
        $rows = 0;
        // Delete the tracker impressions
        $table = $this->conf['table']['data_raw_tracker_impression'];
        $query = "
            DELETE FROM
                $table
            WHERE
                date_time <= '" . $deleteDate->format('%Y-%m-%d %H:%M:%S') ."'";
        debug("Deleting summarised (earlier than '" . $deleteDate->format('%Y-%m-%d %H:%M:%S') .
              "') tracker impressions from the $table table", PEAR_LOG_DEBUG);
        $this->execute($query, $result);
        $rows += $this->affectedRows();
        // Delete the tracker variable values
        $table = $this->conf['table']['data_raw_tracker_variable_value'];
        $query = "
            DELETE FROM
                $table
            WHERE
                date_time <= '" . $deleteDate->format('%Y-%m-%d %H:%M:%S') ."'";
        debug("Deleting summarised (earlier than '" . $deleteDate->format('%Y-%m-%d %H:%M:%S') .
              "') tracker variable values from the $table table", PEAR_LOG_DEBUG);
        $this->execute($query, $result);
        $rows += $this->affectedRows();
        // Delete the tracker clicks
        $table = $this->conf['table']['data_raw_tracker_click'];
        $query = "
            DELETE FROM
                $table
            WHERE
                date_time <= '" . $deleteDate->format('%Y-%m-%d %H:%M:%S') ."'";
        debug("Deleting summarised (earlier than '" . $deleteDate->format('%Y-%m-%d %H:%M:%S') .
              "') tracker clicks from the $table table", PEAR_LOG_DEBUG);
        $this->execute($query, $result);
        $rows += $this->affectedRows();
        return $rows;
    }
    
    /**
     * A method to store the details logging a maintenance statistics
     * run.
     *
     * @param Date $start The time that the maintenance statistics run
     *                    started.
     * @param Date $end The time that the maintenance statistics run
     *                  ended.
     * @param integer $type The type of run:
     *                          0 - The update was based on the operation interval;
     *                          1 - The update was based on the hour;
     *                          2 - The update was based on both the operation interval and hour.
     * @param Date $updateTo The end of the operation interval/hour that has been updated.
     * @param string $report The maintenance statistics run report.
     */
    function logCompletion($start, $end, $type, $updateTo, &$report) {
        $duration = new Date_Span();
        $duration->setFromDateDiff($start, $end);
        $query = "
            INSERT INTO
                {$this->conf['table']['log_maintenance_statistics']}
                (
                    start_run,
                    end_run,
                    duration,
                    tracker_run_type,
                    updated_to
                )
            VALUES
                (
                    '".$start->format('%Y-%m-%d %H:%M:%S')."',
                    '".$end->format('%Y-%m-%d %H:%M:%S')."',
                    ".$duration->toSeconds().",
                    $type,
                    '".$updateTo->format('%Y-%m-%d %H:%M:%S')."'
                )";
        debug('Logging the maintenance statistics run information', PEAR_LOG_DEBUG);
        $this->execute($query, $result);
        $query = "
            INSERT INTO
                {$this->conf['table']['userlog']}
                (
                    timestamp,
                    usertype,
                    userid,
                    action,
                    object,
                    details
                )
            VALUES
                (
                    '".time()."',
                    '".phpAds_userMaintenance."',
                    0,
                    '".phpAds_actionBatchStatistics."',
                    0,
                    '".addslashes($report)."'
                )";
        debug('Logging the maintenance statistics run report', PEAR_LOG_DEBUG);
        $this->execute($query, $result);
    }
    
}

?>
