<?php

/*
+---------------------------------------------------------------------------+
| Max Media Manager v0.2                                                    |
| =================                                                         |
|                                                                           |
| Copyright (c) 2003-2005 Awarez Ltd.                                       |
| For contact details, see: http://www.awarez.net/                          |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: TestOfStatisticsAdServerSplit.php 1239 2005-01-17 17:39:11Z andrew $
*/

/**
 * @package    MaxDal
 * @subpackage TestSuite
 * @author     Andrew Hill <andrew@awarez.net>
 */

require_once maintenancePath . '/libraries/max/Dal/StatisticsAdServerSplit.php';

/**
 * A class for testing the Dal_Statistics_AdServerSplit class.
 */
class Dal_TestOfStatisticsAdServerSplit extends UnitTestCase
{
    
    /**
     * The constructor method.
     */
    function Dal_TestOfStatisticsAdServerSplit()
    {
        $this->UnitTestCase();
    }
    
    /**
     * Tests that the singleton() method only ever returns one class instance.
     */
    function testSingleton()
    {
        debug('Running test', PEAR_LOG_INFO);
        $first =& Dal_Statistics_AdServer_Split::singleton();
        $second =& Dal_Statistics_AdServer_Split::singleton();
        $this->assertIdentical($first, $second);
    }
    
    /**
     * Tests the getMaintenanceStatisticsLastRunInfo() method.
     */
    function testGetMaintenanceStatisticsLastRunInfo()
    {
        debug('Running test', PEAR_LOG_INFO);
        $conf =& $GLOBALS['_MAX']['CONF'];
        $conf['table']['split'] = true;
        $conf['maintenance']['operation_interval'] = 60;
        $dsa =& Dal_Statistics_AdServer_Split::singleton();
        // Create the required tables
        $now = new Date();
        $dsa->tables->createTable('data_raw_ad_impression', $now);
        $dsa->tables->createTable('log_maintenance_statistics');
        // Test with no data
        $date = $dsa->getMaintenanceStatisticsLastRunInfo(0);
        $this->assertNull($date);
        $date = $dsa->getMaintenanceStatisticsLastRunInfo(1);
        $this->assertNull($date);
        // Insert ad impressions
        $now->setHour(18);
        $now->setMinute(22);
        $now->setSecond(10);
        $query = "
            INSERT INTO
                max_data_raw_ad_impression_". $now->format('%Y%m%d') ."
                (
                    date_time
                )
            VALUES
                (
                    '" . $now->format('%Y-%m-%d %H:%M:%S') . "'
                )";
        $dsa->execute($query, $result);
        $now->setHour(12);
        $now->setMinute(34);
        $now->setSecond(56);
        $query = "
            INSERT INTO
                max_data_raw_ad_impression_". $now->format('%Y%m%d') ."
                (
                    date_time
                )
            VALUES
                (
                    '" . $now->format('%Y-%m-%d %H:%M:%S') . "'
                )";
        $dsa->execute($query, $result);
        $now->setHour(18);
        $now->setMinute(22);
        $now->setSecond(11);
        $query = "
            INSERT INTO
                max_data_raw_ad_impression_". $now->format('%Y%m%d') ."
                (
                    date_time
                )
            VALUES
                (
                    '" . $now->format('%Y-%m-%d %H:%M:%S') . "'
                )";
        $dsa->execute($query, $result);
        $now->setHour(11);
        $now->setMinute(59);
        $now->setSecond(59);
        // Test
        $date = $dsa->getMaintenanceStatisticsLastRunInfo(0);
        $this->assertEqual($date, $now);
        $date = $dsa->getMaintenanceStatisticsLastRunInfo(1);
        $this->assertEqual($date, $now);
        // Get the data for the tests
        require_once maintenancePath . '/libraries/max/Dal/data/TestOfStatisticsAdServerSplit.php';
        // Insert an hourly (only) update
        $dsa->execute(SPLIT_LMS_HOUR, $result);
        // Test
        $date = $dsa->getMaintenanceStatisticsLastRunInfo(0);
        $this->assertEqual($date, $now);
        $date = $dsa->getMaintenanceStatisticsLastRunInfo(1);
        $this->assertEqual($date, new Date('2004-06-06 10:15:00'));
        // Insert an operation interval (only) update
        $dsa->execute(SPLIT_LMS_OI, $result);
        // Test
        $date = $dsa->getMaintenanceStatisticsLastRunInfo(0);
        $this->assertEqual($date, new Date('2004-06-06 10:16:00'));
        $date = $dsa->getMaintenanceStatisticsLastRunInfo(1);
        $this->assertEqual($date, new Date('2004-06-06 10:15:00'));
        // Insert a dual interval update
        $dsa->execute(SPLIT_LMS_DUAL, $result);
        // Test
        $date = $dsa->getMaintenanceStatisticsLastRunInfo(0);
        $this->assertEqual($date, new Date('2004-06-07 01:15:00'));
        $date = $dsa->getMaintenanceStatisticsLastRunInfo(1);
        $this->assertEqual($date, new Date('2004-06-07 01:15:00'));
        // Drop the tables
        $dsa->tables->dropTable($conf['table']['data_raw_ad_impression'] . '_' . $now->format('%Y%m%d'));
        $dsa->tables->dropTable($conf['table']['log_maintenance_statistics']);
    }

    /**
     * Tests the summariseRequests() method.
     */
    function testSummariseRequests()
    {
        debug('Running test', PEAR_LOG_INFO);
        $conf =& $GLOBALS['_MAX']['CONF'];
        $conf['maintenance']['operation_interval'] = 30;
        $conf['table']['split'] = true;
        $dsa =& Dal_Statistics_AdServer_Split::singleton();
        // Create the required tables
        $now = new Date('2004-05-06');
        $dsa->tables->createTable('data_raw_ad_request', $now);
        $now = new Date('2004-06-06');
        $dsa->tables->createTable('data_raw_ad_request', $now);
        // Test with no data
        $start = new Date('2004-06-06 12:00:00');
        $end = new Date('2004-06-06 12:29:59');
        $rows = $dsa->summariseRequests($start, $end);
        $this->assertEqual($rows, 0);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                tmp_ad_request";
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 0);
        // Get the data for the tests
        require_once maintenancePath . '/libraries/max/Dal/data/TestOfStatisticsAdServerSplit.php';
        // Insert 3 ad requests
        $dsa->execute(SPLIT_SUMMARISE_AD_REQUESTS_ONE, $result);
        $dsa->execute(SPLIT_SUMMARISE_AD_REQUESTS_TWO, $result);
        // Summarise where requests don't exist
        $start = new Date('2004-05-06 12:00:00');
        $end = new Date('2004-05-06 12:29:59');
        $rows = $dsa->summariseRequests($start, $end);
        $this->assertEqual($rows, 0);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                tmp_ad_request";
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 0);
        // Summarise where one request exists
        $start = new Date('2004-05-06 12:30:00');
        $end = new Date('2004-05-06 12:59:59');
        $rows = $dsa->summariseRequests($start, $end);
        $this->assertEqual($rows, 1);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                tmp_ad_request";
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 1);
        // Summarise where the other two requests exists
        $start = new Date('2004-06-06 18:00:00');
        $end = new Date('2004-06-06 18:29:59');
        $rows = $dsa->summariseRequests($start, $end);
        $this->assertEqual($rows, 1);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                tmp_ad_request
            WHERE
                day = '2004-05-06'";
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 1);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                tmp_ad_request
            WHERE
                day = '2004-06-06'";
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 1);
        $query = "
            SELECT
                requests AS requests
            FROM
                tmp_ad_request
            WHERE
                day = '2004-06-06'";
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['requests'], 2);    
        // Drop the tables
        $dsa->tempTables->dropTempTable('tmp_ad_request');
        $now = new Date('2004-05-06');
        $dsa->tables->dropTable($conf['table']['data_raw_ad_request'] . '_' . $now->format('%Y%m%d'));
        $now = new Date('2004-06-06');
        $dsa->tables->dropTable($conf['table']['data_raw_ad_request'] . '_' . $now->format('%Y%m%d'));
    }

    /**
     * Tests the summariseImpressions() method.
     */
    function testSummariseImpressions()
    {
        debug('Running test', PEAR_LOG_INFO);
        $conf =& $GLOBALS['_MAX']['CONF'];
        $conf['maintenance']['operation_interval'] = 30;
        $conf['table']['split'] = true;
        $dsa =& Dal_Statistics_AdServer_Split::singleton();
        // Create the required tables
        $now = new Date('2004-05-06');
        $dsa->tables->createTable('data_raw_ad_impression', $now);
        $now = new Date('2004-06-06');
        $dsa->tables->createTable('data_raw_ad_impression', $now);
        // Test with no data
        $start = new Date('2004-06-06 12:00:00');
        $end = new Date('2004-06-06 12:29:59');
        $rows = $dsa->summariseImpressions($start, $end);
        $this->assertEqual($rows, 0);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                tmp_ad_impression";
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 0);
        // Get the data for the tests
        require_once maintenancePath . '/libraries/max/Dal/data/TestOfStatisticsAdServerSplit.php';
        // Insert 3 ad impressions
        $dsa->execute(SPLIT_SUMMARISE_AD_IMPRESSIONS_ONE, $result);
        $dsa->execute(SPLIT_SUMMARISE_AD_IMPRESSIONS_TWO, $result);
        // Summarise where impressions don't exist
        $start = new Date('2004-05-06 12:00:00');
        $end = new Date('2004-05-06 12:29:59');
        $rows = $dsa->summariseImpressions($start, $end);
        $this->assertEqual($rows, 0);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                tmp_ad_impression";
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 0);
        // Summarise where one impression exists
        $start = new Date('2004-05-06 12:30:00');
        $end = new Date('2004-05-06 12:59:59');
        $rows = $dsa->summariseImpressions($start, $end);
        $this->assertEqual($rows, 1);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                tmp_ad_impression";
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 1);
        // Summarise where the other two impression exists
        $start = new Date('2004-06-06 18:00:00');
        $end = new Date('2004-06-06 18:29:59');
        $rows = $dsa->summariseImpressions($start, $end);
        $this->assertEqual($rows, 1);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                tmp_ad_impression
            WHERE
                day = '2004-05-06'";
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 1);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                tmp_ad_impression
            WHERE
                day = '2004-06-06'";
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 1);
        $query = "
            SELECT
                impressions AS impressions
            FROM
                tmp_ad_impression
            WHERE
                day = '2004-06-06'";
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['impressions'], 2);    
        // Drop the tables
        $dsa->tempTables->dropTempTable('tmp_ad_impression');
        $now = new Date('2004-05-06');
        $dsa->tables->dropTable($conf['table']['data_raw_ad_impression'] . '_' . $now->format('%Y%m%d'));
        $now = new Date('2004-06-06');
        $dsa->tables->dropTable($conf['table']['data_raw_ad_impression'] . '_' . $now->format('%Y%m%d'));
    }
    
    /**
     * Tests the summariseClicks() method.
     */
    function testSummariseClicks()
    {
        debug('Running test', PEAR_LOG_INFO);
        $conf =& $GLOBALS['_MAX']['CONF'];
        $conf['maintenance']['operation_interval'] = 30;
        $conf['table']['split'] = true;
        $dsa =& Dal_Statistics_AdServer_Split::singleton();
        // Create the required tables
        $now = new Date('2004-05-06');
        $dsa->tables->createTable('data_raw_ad_click', $now);
        $now = new Date('2004-06-06');
        $dsa->tables->createTable('data_raw_ad_click', $now);
        // Test with no data
        $start = new Date('2004-06-06 12:00:00');
        $end = new Date('2004-06-06 12:29:59');
        $rows = $dsa->summariseClicks($start, $end);
        $this->assertEqual($rows, 0);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                tmp_ad_click";
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 0);
        // Get the data for the tests
        require_once maintenancePath . '/libraries/max/Dal/data/TestOfStatisticsAdServerSplit.php';
        // Insert 3 ad clicks
        $dsa->execute(SPLIT_SUMMARISE_AD_CLICKS_ONE, $result);
        $dsa->execute(SPLIT_SUMMARISE_AD_CLICKS_TWO, $result);
        // Summarise where clicks don't exist
        $start = new Date('2004-05-06 12:00:00');
        $end = new Date('2004-05-06 12:29:59');
        $rows = $dsa->summariseClicks($start, $end);
        $this->assertEqual($rows, 0);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                tmp_ad_click";
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 0);
        // Summarise where one click exists
        $start = new Date('2004-05-06 12:30:00');
        $end = new Date('2004-05-06 12:59:59');
        $rows = $dsa->summariseClicks($start, $end);
        $this->assertEqual($rows, 1);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                tmp_ad_click";
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 1);
        // Summarise where the other two clicks exists
        $start = new Date('2004-06-06 18:00:00');
        $end = new Date('2004-06-06 18:29:59');
        $rows = $dsa->summariseClicks($start, $end);
        $this->assertEqual($rows, 1);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                tmp_ad_click
            WHERE
                day = '2004-05-06'";
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 1);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                tmp_ad_click
            WHERE
                day = '2004-06-06'";
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 1);
        $query = "
            SELECT
                clicks AS clicks
            FROM
                tmp_ad_click
            WHERE
                day = '2004-06-06'";
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['clicks'], 2);    
        // Drop the tables
        $dsa->tempTables->dropTempTable('tmp_ad_click');
        $now = new Date('2004-05-06');
        $dsa->tables->dropTable($conf['table']['data_raw_ad_click'] . '_' . $now->format('%Y%m%d'));
        $now = new Date('2004-06-06');
        $dsa->tables->dropTable($conf['table']['data_raw_ad_click'] . '_' . $now->format('%Y%m%d'));
    }
    
    /**
     * Tests the summariseConnections() method.
     */
    function testSummariseConnections()
    {
        debug('Running test', PEAR_LOG_INFO);
        $conf =& $GLOBALS['_MAX']['CONF'];
        $conf['maintenance']['operation_interval'] = 30;
        $conf['table']['split'] = true;
        $conf['modules']['Tracker'] = true;
        $dsa =& Dal_Statistics_AdServer_Split::singleton();
        // Create the required tables
        $dsa->tables->createTable('banners');
        $dsa->tables->createTable('campaigns_trackers');
        $now = new Date('2004-05-06');
        $dsa->tables->createTable('data_raw_ad_click', $now);
        $dsa->tables->createTable('data_raw_ad_impression', $now);
        $dsa->tables->createTable('data_raw_tracker_impression', $now);
        $now = new Date('2004-06-06');
        $dsa->tables->createTable('data_raw_ad_click', $now);
        $dsa->tables->createTable('data_raw_ad_impression', $now);
        $dsa->tables->createTable('data_raw_tracker_impression', $now);
        // Test with no data
        $start = new Date('2004-06-06 12:00:00');
        $end = new Date('2004-06-06 12:29:59');
        $rows = $dsa->summariseConnections($start, $end);
        $this->assertEqual($rows, 0);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                tmp_ad_connection";
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 0);
        // Get the data for the tests
        require_once maintenancePath . '/libraries/max/Dal/data/TestOfStatisticsAdServerSplit.php';
        // Insert some ads (banners), campaign trackers, ad
        // impressions, ad clicks, and tracker impressions
        $dsa->execute(SPLIT_SUMMARISE_CONVERSIONS_BANNERS, $result);
        $dsa->execute(SPLIT_SUMMARISE_CONVERSIONS_CAMPAIGNS_TRACKERS, $result);
        $dsa->execute(SPLIT_SUMMARISE_CONVERSIONS_AD_IMPRESSIONS_ONE, $result);
        $dsa->execute(SPLIT_SUMMARISE_CONVERSIONS_AD_IMPRESSIONS_TWO, $result);
        $dsa->execute(SPLIT_SUMMARISE_CONVERSIONS_AD_CLICKS_ONE, $result);
        $dsa->execute(SPLIT_SUMMARISE_CONVERSIONS_AD_CLICKS_TWO, $result);
        $dsa->execute(SPLIT_SUMMARISE_CONVERSIONS_TRACKER_IMPRESSIONS_ONE, $result);
        $dsa->execute(SPLIT_SUMMARISE_CONVERSIONS_TRACKER_IMPRESSIONS_TWO, $result);
        // Summarise where tracker impressions don't exist
        $start = new Date('2004-05-06 12:00:00');
        $end = new Date('2004-05-06 12:29:59');
        $rows = $dsa->summariseConnections($start, $end);
        $this->assertEqual($rows, 0);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                tmp_ad_connection";
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 0);
        // Summarise where just one tracker impression exists
        $start = new Date('2004-05-06 12:30:00');
        $end = new Date('2004-05-06 12:59:59');
        $rows = $dsa->summariseConnections($start, $end);
        $this->assertEqual($rows, 2);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                tmp_ad_connection";
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 2);
        $query = "
            SELECT
                *
            FROM
                tmp_ad_connection
            WHERE
                connection_type = 0";
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['server_raw_tracker_impression_id'], 2);
        $this->assertEqual($row['connection_viewer_id'], 'aa');
        $this->assertEqual($row['connection_viewer_session_id'], 0);
        $this->assertEqual($row['connection_date_time'], '2004-05-06 12:34:56');
        $this->assertEqual($row['connection_ad_id'], 2);
        $this->assertEqual($row['connection_creative_id'], 0);
        $this->assertEqual($row['connection_zone_id'], 0);
        $this->assertEqual($row['connection_channel'], 'chan2');
        $this->assertEqual($row['connection_language'], 'en2');
        $this->assertEqual($row['connection_ip_address'], '127.0.0.2');
        $this->assertEqual($row['connection_host_name'], 'localhost2');
        $this->assertEqual($row['connection_country'], 'U2');
        $this->assertEqual($row['connection_https'], 0);
        $this->assertEqual($row['connection_domain'], 'domain2');
        $this->assertEqual($row['connection_page'], 'page2');
        $this->assertEqual($row['connection_query'], 'query2');
        $this->assertEqual($row['connection_referer'], 'referer2');
        $this->assertEqual($row['connection_search_term'], 'term2');
        $this->assertEqual($row['connection_user_agent'], 'agent2');
        $this->assertEqual($row['connection_os'], 'linux2');
        $this->assertEqual($row['connection_browser'], 'mozilla2');
        $this->assertEqual($row['connection_type'], 0);
        $this->assertEqual($row['connection_window'], 2592000);
        $this->assertEqual($row['conversion'], 0);
        $this->assertEqual($row['latest'], 0);
        $query = "
            SELECT
                *
            FROM
                tmp_ad_connection
            WHERE
                connection_type = 1";
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['server_raw_tracker_impression_id'], 2);
        $this->assertEqual($row['connection_viewer_id'], 'aa');
        $this->assertEqual($row['connection_viewer_session_id'], 0);
        $this->assertEqual($row['connection_date_time'], '2004-05-06 12:34:56');
        $this->assertEqual($row['connection_ad_id'], 2);
        $this->assertEqual($row['connection_creative_id'], 0);
        $this->assertEqual($row['connection_zone_id'], 0);
        $this->assertEqual($row['connection_channel'], 'chan2');
        $this->assertEqual($row['connection_language'], 'en2');
        $this->assertEqual($row['connection_ip_address'], '127.0.0.2');
        $this->assertEqual($row['connection_host_name'], 'localhost2');
        $this->assertEqual($row['connection_country'], 'U2');
        $this->assertEqual($row['connection_https'], 0);
        $this->assertEqual($row['connection_domain'], 'domain2');
        $this->assertEqual($row['connection_page'], 'page2');
        $this->assertEqual($row['connection_query'], 'query2');
        $this->assertEqual($row['connection_referer'], 'referer2');
        $this->assertEqual($row['connection_search_term'], 'term2');
        $this->assertEqual($row['connection_user_agent'], 'agent2');
        $this->assertEqual($row['connection_os'], 'linux2');
        $this->assertEqual($row['connection_browser'], 'mozilla2');
        $this->assertEqual($row['connection_type'], 1);
        $this->assertEqual($row['connection_window'], 2592000);
        $this->assertEqual($row['conversion'], 0);
        $this->assertEqual($row['latest'], 0);
        // Drop the temporary table
        $dsa->tempTables->dropTempTable('tmp_ad_connection');
        // Summarise where the other connections are        
        $start = new Date('2004-06-06 18:00:00');
        $end = new Date('2004-06-06 18:29:59');
        $rows = $dsa->summariseConnections($start, $end);
        $this->assertEqual($rows, 4);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                tmp_ad_connection";
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 4);
        $query = "
            SELECT
                *
            FROM
                tmp_ad_connection
            WHERE
                connection_type = 1
                AND connection_ad_id = 3";
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['server_raw_tracker_impression_id'], 3);
        $this->assertEqual($row['connection_viewer_id'], 'aa');
        $this->assertEqual($row['connection_viewer_session_id'], 0);
        $this->assertEqual($row['connection_date_time'], '2004-06-06 18:22:11');
        $this->assertEqual($row['connection_ad_id'], 3);
        $this->assertEqual($row['connection_creative_id'], 0);
        $this->assertEqual($row['connection_zone_id'], 0);
        $this->assertEqual($row['connection_channel'], 'chan3');
        $this->assertEqual($row['connection_language'], 'en3');
        $this->assertEqual($row['connection_ip_address'], '127.0.0.3');
        $this->assertEqual($row['connection_host_name'], 'localhost3');
        $this->assertEqual($row['connection_country'], 'U3');
        $this->assertEqual($row['connection_https'], 0);
        $this->assertEqual($row['connection_domain'], 'domain3');
        $this->assertEqual($row['connection_page'], 'page3');
        $this->assertEqual($row['connection_query'], 'query3');
        $this->assertEqual($row['connection_referer'], 'referer3');
        $this->assertEqual($row['connection_search_term'], 'term3');
        $this->assertEqual($row['connection_user_agent'], 'agent3');
        $this->assertEqual($row['connection_os'], 'linux3');
        $this->assertEqual($row['connection_browser'], 'mozilla3');
        $this->assertEqual($row['connection_type'], 1);
        $this->assertEqual($row['connection_window'], 2592000);
        $this->assertEqual($row['conversion'], 'y');
        $this->assertEqual($row['latest'], 0);
        $query = "
            SELECT
                *
            FROM
                tmp_ad_connection
            WHERE
                connection_type = 1
                AND connection_ad_id = 4";
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['server_raw_tracker_impression_id'], 3);
        $this->assertEqual($row['connection_viewer_id'], 'aa');
        $this->assertEqual($row['connection_viewer_session_id'], 0);
        $this->assertEqual($row['connection_date_time'], '2004-06-06 18:22:12');
        $this->assertEqual($row['connection_ad_id'], 4);
        $this->assertEqual($row['connection_creative_id'], 0);
        $this->assertEqual($row['connection_zone_id'], 0);
        $this->assertEqual($row['connection_channel'], 'chan4');
        $this->assertEqual($row['connection_language'], 'en4');
        $this->assertEqual($row['connection_ip_address'], '127.0.0.4');
        $this->assertEqual($row['connection_host_name'], 'localhost4');
        $this->assertEqual($row['connection_country'], 'U4');
        $this->assertEqual($row['connection_https'], 0);
        $this->assertEqual($row['connection_domain'], 'domain4');
        $this->assertEqual($row['connection_page'], 'page4');
        $this->assertEqual($row['connection_query'], 'query4');
        $this->assertEqual($row['connection_referer'], 'referer4');
        $this->assertEqual($row['connection_search_term'], 'term4');
        $this->assertEqual($row['connection_user_agent'], 'agent4');
        $this->assertEqual($row['connection_os'], 'linux4');
        $this->assertEqual($row['connection_browser'], 'mozilla4');
        $this->assertEqual($row['connection_type'], 1);
        $this->assertEqual($row['connection_window'], 2592000);
        $this->assertEqual($row['conversion'], 'y');
        $this->assertEqual($row['latest'], 0);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                tmp_ad_connection";
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 4);
        $query = "
            SELECT
                *
            FROM
                tmp_ad_connection
            WHERE
                connection_type = 0
                AND connection_ad_id = 3";
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['server_raw_tracker_impression_id'], 3);
        $this->assertEqual($row['connection_viewer_id'], 'aa');
        $this->assertEqual($row['connection_viewer_session_id'], 0);
        $this->assertEqual($row['connection_date_time'], '2004-06-06 18:22:11');
        $this->assertEqual($row['connection_ad_id'], 3);
        $this->assertEqual($row['connection_creative_id'], 0);
        $this->assertEqual($row['connection_zone_id'], 0);
        $this->assertEqual($row['connection_channel'], 'chan3');
        $this->assertEqual($row['connection_language'], 'en3');
        $this->assertEqual($row['connection_ip_address'], '127.0.0.3');
        $this->assertEqual($row['connection_host_name'], 'localhost3');
        $this->assertEqual($row['connection_country'], 'U3');
        $this->assertEqual($row['connection_https'], 0);
        $this->assertEqual($row['connection_domain'], 'domain3');
        $this->assertEqual($row['connection_page'], 'page3');
        $this->assertEqual($row['connection_query'], 'query3');
        $this->assertEqual($row['connection_referer'], 'referer3');
        $this->assertEqual($row['connection_search_term'], 'term3');
        $this->assertEqual($row['connection_user_agent'], 'agent3');
        $this->assertEqual($row['connection_os'], 'linux3');
        $this->assertEqual($row['connection_browser'], 'mozilla3');
        $this->assertEqual($row['connection_type'], 0);
        $this->assertEqual($row['connection_window'], 2592000);
        $this->assertEqual($row['conversion'], 'y');
        $this->assertEqual($row['latest'], 0);
        $query = "
            SELECT
                *
            FROM
                tmp_ad_connection
            WHERE
                connection_type = 0
                AND connection_ad_id = 4";
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['server_raw_tracker_impression_id'], 3);
        $this->assertEqual($row['connection_viewer_id'], 'aa');
        $this->assertEqual($row['connection_viewer_session_id'], 0);
        $this->assertEqual($row['connection_date_time'], '2004-06-06 18:22:12');
        $this->assertEqual($row['connection_ad_id'], 4);
        $this->assertEqual($row['connection_creative_id'], 0);
        $this->assertEqual($row['connection_zone_id'], 0);
        $this->assertEqual($row['connection_channel'], 'chan4');
        $this->assertEqual($row['connection_language'], 'en4');
        $this->assertEqual($row['connection_ip_address'], '127.0.0.4');
        $this->assertEqual($row['connection_host_name'], 'localhost4');
        $this->assertEqual($row['connection_country'], 'U4');
        $this->assertEqual($row['connection_https'], 0);
        $this->assertEqual($row['connection_domain'], 'domain4');
        $this->assertEqual($row['connection_page'], 'page4');
        $this->assertEqual($row['connection_query'], 'query4');
        $this->assertEqual($row['connection_referer'], 'referer4');
        $this->assertEqual($row['connection_search_term'], 'term4');
        $this->assertEqual($row['connection_user_agent'], 'agent4');
        $this->assertEqual($row['connection_os'], 'linux4');
        $this->assertEqual($row['connection_browser'], 'mozilla4');
        $this->assertEqual($row['connection_type'], 0);
        $this->assertEqual($row['connection_window'], 2592000);
        $this->assertEqual($row['conversion'], 'y');
        $this->assertEqual($row['latest'], 0);
        // Drop the temporary table
        $dsa->tempTables->dropTempTable('tmp_ad_connection');  
        // Test with the data present, but the tracker module uninstalled
        $conf['modules']['Tracker'] = false;
        // Summarise where the other connections are        
        $start = new Date('2004-06-06 18:00:00');
        $end = new Date('2004-06-06 18:29:59');
        $rows = $dsa->summariseConnections($start, $end);
        $this->assertEqual($rows, 0);
        // Drop the tables
        $dsa->tables->dropTable($conf['table']['banners']);
        $dsa->tables->dropTable($conf['table']['campaigns_trackers']);
        $now = new Date('2004-05-06');
        $dsa->tables->dropTable($conf['table']['data_raw_ad_click'] . '_' . $now->format('%Y%m%d'));
        $dsa->tables->dropTable($conf['table']['data_raw_ad_impression'] . '_' . $now->format('%Y%m%d'));
        $dsa->tables->dropTable($conf['table']['data_raw_tracker_impression'] . '_' . $now->format('%Y%m%d'));
        $now = new Date('2004-06-06');
        $dsa->tables->dropTable($conf['table']['data_raw_ad_click'] . '_' . $now->format('%Y%m%d'));
        $dsa->tables->dropTable($conf['table']['data_raw_ad_impression'] . '_' . $now->format('%Y%m%d'));
        $dsa->tables->dropTable($conf['table']['data_raw_tracker_impression'] . '_' . $now->format('%Y%m%d'));
    }
    
    /**
     * Tests the saveIntermediate() method.
     */
    function testSaveIntermediate()
    {
        debug('Running test', PEAR_LOG_INFO);
        $conf =& $GLOBALS['_MAX']['CONF'];
        $conf['maintenance']['operation_interval'] = 30;
        $conf['table']['split'] = true;
        $conf['modules']['Tracker'] = true;
        $dsa =& Dal_Statistics_AdServer_Split::singleton();
        // Create the required tables
        $dsa->tempTables->createTable('tmp_ad_click');
        $dsa->tempTables->createTable('tmp_ad_connection');
        $dsa->tempTables->createTable('tmp_ad_impression');
        $dsa->tempTables->createTable('tmp_ad_request');
        $dsa->tables->createTable('data_intermediate_ad');
        $dsa->tables->createTable('data_intermediate_ad_connection');
        $dsa->tables->createTable('data_intermediate_ad_variable_value');
        $now = new Date('2004-06-06');
        $dsa->tables->createTable('data_raw_tracker_impression', $now);
        $dsa->tables->createTable('data_raw_tracker_variable_value', $now);
        $now = new Date('2004-06-07');
        $dsa->tables->createTable('data_raw_tracker_variable_value', $now);
        $dsa->tables->createTable('variables');
        // Test with no data
        $start = new Date('2004-06-06 12:00:00');
        $end = new Date('2004-06-06 12:29:59');
        $dsa->saveIntermediate($start, $end);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_intermediate_ad_connection']}";
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 0);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_intermediate_ad_variable_value']}";
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 0);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_intermediate_ad']}";
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 0);
        // Re-create dropped tables
        $dsa->tempTables->createTable('tmp_ad_click');
        $dsa->tempTables->createTable('tmp_ad_connection');
        $dsa->tempTables->createTable('tmp_ad_impression');
        $dsa->tempTables->createTable('tmp_ad_request');
        // Get the data for the tests
        require_once maintenancePath . '/libraries/max/Dal/data/TestOfStatisticsAdServerSplit.php';
        // Insert the test data
        $dsa->execute(SPLIT_SAVE_INTERMEDIATE_VARIABLES, $result);
        $dsa->execute(SPLIT_SAVE_INTERMEDIATE_AD_CLICKS, $result);
        $dsa->execute(SPLIT_SAVE_INTERMEDIATE_AD_IMPRESSIONS, $result);
        $dsa->execute(SPLIT_SAVE_INTERMEDIATE_TRACKER_IMPRESSIONS, $result);
        $dsa->execute(SPLIT_SAVE_INTERMEDIATE_TRACKER_VARIABLE_VALUES_ONE, $result);
        $dsa->execute(SPLIT_SAVE_INTERMEDIATE_TRACKER_VARIABLE_VALUES_TWO, $result);
        $dsa->execute(SPLIT_SAVE_INTERMEDIATE_CONNECTIONS, $result);
        // Test
        $start = new Date('2004-06-06 18:00:00');
        $end = new Date('2004-06-06 18:29:59');
        $dsa->saveIntermediate($start, $end);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_intermediate_ad_connection']}";
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 2);
        $query = "
            SELECT
                *
            FROM
                {$conf['table']['data_intermediate_ad_connection']}
            WHERE
                server_raw_tracker_impression_id = 1
                AND server_raw_ip = '127.0.0.1'";
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['server_raw_tracker_impression_id'], 1);
        $this->assertEqual($row['server_raw_ip'], '127.0.0.1');
        $this->assertEqual($row['viewer_id'], 'aa');
        $this->assertEqual($row['viewer_session_id'], 1);
        $this->assertEqual($row['tracker_date_time'], '2004-06-06 18:10:15');
        $this->assertEqual($row['connection_date_time'], '2004-06-06 18:00:00');
        $this->assertEqual($row['tracker_id'], 1);
        $this->assertEqual($row['ad_id'], 1);
        $this->assertEqual($row['creative_id'], 1);
        $this->assertEqual($row['zone_id'], 1);
        $this->assertEqual($row['tracker_channel'], 'tchan1');
        $this->assertEqual($row['connection_channel'], 'chan1');
        $this->assertEqual($row['tracker_language'], 'ten1');
        $this->assertEqual($row['connection_language'], 'en1');
        $this->assertEqual($row['tracker_ip_address'], 't127.0.0.1');
        $this->assertEqual($row['connection_ip_address'], '127.0.0.1');
        $this->assertEqual($row['tracker_host_name'], 'thost1');
        $this->assertEqual($row['connection_host_name'], 'host1');
        $this->assertEqual($row['tracker_country'], 'T1');
        $this->assertEqual($row['connection_country'], 'U1');
        $this->assertEqual($row['tracker_https'], 1);
        $this->assertEqual($row['connection_https'], 0);
        $this->assertEqual($row['tracker_domain'], 'tdomain1');
        $this->assertEqual($row['connection_domain'], 'domain1');
        $this->assertEqual($row['tracker_page'], 'tpage1');
        $this->assertEqual($row['connection_page'], 'page1');
        $this->assertEqual($row['tracker_query'], 'tquery1');
        $this->assertEqual($row['connection_query'], 'query1');
        $this->assertEqual($row['tracker_referer'], 'tref1');
        $this->assertEqual($row['connection_referer'], 'ref1');
        $this->assertEqual($row['tracker_search_term'], 'tterm1');
        $this->assertEqual($row['connection_search_term'], 'term1');
        $this->assertEqual($row['tracker_user_agent'], 'tagent1');
        $this->assertEqual($row['connection_user_agent'], 'agent1');
        $this->assertEqual($row['tracker_os'], 'tlinux1');
        $this->assertEqual($row['connection_os'], 'linux1');
        $this->assertEqual($row['tracker_browser'], 'tmozilla1');
        $this->assertEqual($row['connection_browser'], 'mozilla1');
        $this->assertEqual($row['connection_type'], 1);
        $this->assertEqual($row['connection_window'], 259200);
        $this->assertEqual($row['conversion'], 'n');
        $query = "
            SELECT
                *
            FROM
                {$conf['table']['data_intermediate_ad_connection']}
            WHERE
                server_raw_tracker_impression_id = 2
                AND server_raw_ip = '127.0.0.2'";
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['server_raw_tracker_impression_id'], 2);
        $this->assertEqual($row['server_raw_ip'], '127.0.0.2');
        $this->assertEqual($row['viewer_id'], 'bb');
        $this->assertEqual($row['viewer_session_id'], 2);
        $this->assertEqual($row['tracker_date_time'], '2004-06-06 18:22:10');
        $this->assertEqual($row['connection_date_time'], '2004-06-05 10:00:00');
        $this->assertEqual($row['tracker_id'], 2);
        $this->assertEqual($row['ad_id'], 2);
        $this->assertEqual($row['creative_id'], 2);
        $this->assertEqual($row['zone_id'], 2);
        $this->assertEqual($row['tracker_channel'], 'tchan2');
        $this->assertEqual($row['connection_channel'], 'chan2');
        $this->assertEqual($row['tracker_language'], 'ten2');
        $this->assertEqual($row['connection_language'], 'en2');
        $this->assertEqual($row['tracker_ip_address'], 't127.0.0.2');
        $this->assertEqual($row['connection_ip_address'], '127.0.0.2');
        $this->assertEqual($row['tracker_host_name'], 'thost2');
        $this->assertEqual($row['connection_host_name'], 'host2');
        $this->assertEqual($row['tracker_country'], 'T2');
        $this->assertEqual($row['connection_country'], 'U2');
        $this->assertEqual($row['tracker_https'], 1);
        $this->assertEqual($row['connection_https'], 0);
        $this->assertEqual($row['tracker_domain'], 'tdomain2');
        $this->assertEqual($row['connection_domain'], 'domain2');
        $this->assertEqual($row['tracker_page'], 'tpage2');
        $this->assertEqual($row['connection_page'], 'page2');
        $this->assertEqual($row['tracker_query'], 'tquery2');
        $this->assertEqual($row['connection_query'], 'query2');
        $this->assertEqual($row['tracker_referer'], 'tref2');
        $this->assertEqual($row['connection_referer'], 'ref2');
        $this->assertEqual($row['tracker_search_term'], 'tterm2');
        $this->assertEqual($row['connection_search_term'], 'term2');
        $this->assertEqual($row['tracker_user_agent'], 'tagent2');
        $this->assertEqual($row['connection_user_agent'], 'agent2');
        $this->assertEqual($row['tracker_os'], 'tlinux2');
        $this->assertEqual($row['connection_os'], 'linux2');
        $this->assertEqual($row['tracker_browser'], 'tmozilla2');
        $this->assertEqual($row['connection_browser'], 'mozilla2');
        $this->assertEqual($row['connection_type'], 1);
        $this->assertEqual($row['connection_window'], 4320);
        $this->assertEqual($row['conversion'], 'y');
        $this->assertEqual($row['latest'], 0);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_intermediate_ad_variable_value']}";
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 4);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_intermediate_ad_variable_value']} AS diavv,
                {$conf['table']['data_intermediate_ad_connection']} AS diac
            WHERE
                diac.server_raw_tracker_impression_id = 1
                AND diac.server_raw_ip = '127.0.0.1'
                AND diac.data_intermediate_ad_connection_id = diavv.data_intermediate_ad_connection_id";
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 2);
        $query = "
            SELECT
                diavv.*
            FROM
                {$conf['table']['data_intermediate_ad_variable_value']} AS diavv
            WHERE
                diavv.tracker_variable_id = 1";
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['value'], 1);
        $query = "
            SELECT
                diavv.*
            FROM
                {$conf['table']['data_intermediate_ad_variable_value']} AS diavv
            WHERE
                diavv.tracker_variable_id = 2";
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['value'], 2);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_intermediate_ad_variable_value']} AS diavv,
                {$conf['table']['data_intermediate_ad_connection']} AS diac
            WHERE
                diac.server_raw_tracker_impression_id = 2
                AND diac.server_raw_ip = '127.0.0.2'
                AND diac.data_intermediate_ad_connection_id = diavv.data_intermediate_ad_connection_id";
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 2);
        $query = "
            SELECT
                diavv.*
            FROM
                {$conf['table']['data_intermediate_ad_variable_value']} AS diavv
            WHERE
                diavv.tracker_variable_id = 3";
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertNull($row['value']);
        $query = "
            SELECT
                diavv.*
            FROM
                {$conf['table']['data_intermediate_ad_variable_value']} AS diavv                
            WHERE
                diavv.tracker_variable_id = 4";
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['value'], 3);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_intermediate_ad']}";
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 2);
        $query = "
            SELECT
                * 
            FROM
                {$conf['table']['data_intermediate_ad']}
            WHERE
                ad_id = 1";
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['day'], '2004-06-06');
        $this->assertEqual($row['hour'], 18);
        $this->assertEqual($row['operation_interval'], 30);
        $this->assertEqual($row['operation_interval_id'], 36);
        $this->assertEqual($row['interval_start'], '2004-06-06 18:00:00');
        $this->assertEqual($row['creative_id'], 1);
        $this->assertEqual($row['zone_id'], 1);
        $this->assertEqual($row['impressions'], 1);
        $this->assertEqual($row['clicks'], 1);
        $this->assertEqual($row['conversions'], 0);
        $this->assertEqual($row['total_basket_value'], 0);
        $query = "
            SELECT
                * 
            FROM
                {$conf['table']['data_intermediate_ad']}
            WHERE
                ad_id = 2";
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['day'], '2004-06-06');
        $this->assertEqual($row['hour'], 18);
        $this->assertEqual($row['operation_interval'], 30);
        $this->assertEqual($row['operation_interval_id'], 36);
        $this->assertEqual($row['interval_start'], '2004-06-06 18:00:00');
        $this->assertEqual($row['creative_id'], 2);
        $this->assertEqual($row['zone_id'], 2);
        $this->assertEqual($row['impressions'], 2);
        $this->assertEqual($row['clicks'], 2);
        $this->assertEqual($row['conversions'], 1);
        $this->assertEqual($row['total_basket_value'], 3);
        // Drop the tables
        $dsa->tables->dropTable($conf['table']['data_intermediate_ad']);
        $dsa->tables->dropTable($conf['table']['data_intermediate_ad_connection']);
        $dsa->tables->dropTable($conf['table']['data_intermediate_ad_variable_value']);
        $now = new Date('2004-06-06');
        $dsa->tables->dropTable($conf['table']['data_raw_tracker_impression'] . '_' . $now->format('%Y%m%d'));
        $dsa->tables->dropTable($conf['table']['data_raw_tracker_variable_value'] . '_' . $now->format('%Y%m%d'));
        $now = new Date('2004-06-07');
        $dsa->tables->dropTable($conf['table']['data_raw_tracker_variable_value'] . '_' . $now->format('%Y%m%d'));
        $dsa->tables->dropTable($conf['table']['variables']);
        // Test again without the Tracker module installed
        $conf['modules']['Tracker'] = false;
        // Create the (minimum set of) required tables
        $dsa->tempTables->createTable('tmp_ad_click');
        $dsa->tempTables->createTable('tmp_ad_impression');
        $dsa->tempTables->createTable('tmp_ad_request');
        $dsa->tables->createTable('data_intermediate_ad');
        // Test with no data
        $start = new Date('2004-06-06 12:00:00');
        $end = new Date('2004-06-06 12:29:59');
        $dsa->saveIntermediate($start, $end);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_intermediate_ad']}";
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 0);
        // Re-create dropped tables
        $dsa->tempTables->createTable('tmp_ad_click');
        $dsa->tempTables->createTable('tmp_ad_impression');
        $dsa->tempTables->createTable('tmp_ad_request');
        // Insert the test data
        $dsa->execute(SPLIT_SAVE_INTERMEDIATE_AD_CLICKS, $result);
        $dsa->execute(SPLIT_SAVE_INTERMEDIATE_AD_IMPRESSIONS, $result);        
        // Test
        $start = new Date('2004-06-06 18:00:00');
        $end = new Date('2004-06-06 18:29:59');
        $dsa->saveIntermediate($start, $end);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_intermediate_ad']}";
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 2);
        $query = "
            SELECT
                * 
            FROM
                {$conf['table']['data_intermediate_ad']}
            WHERE
                ad_id = 1";
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['day'], '2004-06-06');
        $this->assertEqual($row['hour'], 18);
        $this->assertEqual($row['operation_interval'], 30);
        $this->assertEqual($row['operation_interval_id'], 36);
        $this->assertEqual($row['interval_start'], '2004-06-06 18:00:00');
        $this->assertEqual($row['creative_id'], 1);
        $this->assertEqual($row['zone_id'], 1);
        $this->assertEqual($row['impressions'], 1);
        $this->assertEqual($row['clicks'], 1);
        $this->assertEqual($row['conversions'], 0);
        $this->assertEqual($row['total_basket_value'], 0);
        $query = "
            SELECT
                * 
            FROM
                {$conf['table']['data_intermediate_ad']}
            WHERE
                ad_id = 2";
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['day'], '2004-06-06');
        $this->assertEqual($row['hour'], 18);
        $this->assertEqual($row['operation_interval'], 30);
        $this->assertEqual($row['operation_interval_id'], 36);
        $this->assertEqual($row['interval_start'], '2004-06-06 18:00:00');
        $this->assertEqual($row['creative_id'], 2);
        $this->assertEqual($row['zone_id'], 2);
        $this->assertEqual($row['impressions'], 2);
        $this->assertEqual($row['clicks'], 2);
        $this->assertEqual($row['conversions'], 0);
        $this->assertEqual($row['total_basket_value'], 0);
        // Drop the tables
        $dsa->tables->dropTable($conf['table']['data_intermediate_ad']);
    }

    /**
     * Tests the deleteOldData() method.
     */
    function testDeleteOldData()
    {
        debug('Running test', PEAR_LOG_INFO);
        $conf =& $GLOBALS['_MAX']['CONF'];
        $conf['table']['split'] = true;
        $conf['maintenance']['compact_stats_grace'] = 0;
        $dsa =& Dal_Statistics_AdServer_Split::singleton();
        // Enable the tracker
        $conf['modules']['Tracker'] = true;
        // Create the required tables
        $dsa->tables->createTable('campaigns_trackers');
        $now = new Date('2004-06-05');
        $dsa->tables->createTable('data_raw_ad_click', $now);
        $dsa->tables->createTable('data_raw_ad_impression', $now);
        $dsa->tables->createTable('data_raw_ad_request', $now);
        $now = new Date('2004-06-06');
        $dsa->tables->createTable('data_raw_ad_click', $now);
        $dsa->tables->createTable('data_raw_ad_impression', $now);
        $dsa->tables->createTable('data_raw_ad_request', $now);
        // Get the data for the tests
        require_once maintenancePath . '/libraries/max/Dal/data/TestOfStatisticsAdServerSplit.php';
        // Insert the test data
        $dsa->execute(SPLIT_DELETE_OLD_DATA_CAMPAIGNS_TRACKERS, $result);
        $dsa->execute(SPLIT_DELETE_OLD_DATA_AD_CLICKS_ONE, $result);
        $dsa->execute(SPLIT_DELETE_OLD_DATA_AD_CLICKS_TWO, $result);
        $dsa->execute(SPLIT_DELETE_OLD_DATA_AD_IMPRESSIONS_ONE, $result);
        $dsa->execute(SPLIT_DELETE_OLD_DATA_AD_IMPRESSIONS_TWO, $result);
        $dsa->execute(SPLIT_DELETE_OLD_DATA_AD_REQUESTS_ONE, $result);
        $dsa->execute(SPLIT_DELETE_OLD_DATA_AD_REQUESTS_TWO, $result);
        // Test
        $summarisedTo = new Date('2004-06-06 17:59:59');
        $dsa->deleteOldData($summarisedTo);
        $now = new Date('2004-06-05');
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_raw_ad_click']}_" . $now->format('%Y%m%d');
        $errors = array(1146);   // Permit the table does not exist error
        $errorID = $dsa->executeIgnoreErrors($query, $result, $errors);
        $this->assertEqual($errorID, 1146);
        $now = new Date('2004-06-06');
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_raw_ad_click']}_" . $now->format('%Y%m%d');
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 6);
        $now = new Date('2004-06-05');
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_raw_ad_impression']}_" . $now->format('%Y%m%d');
        $errors = array(1146);   // Permit the table does not exist error
        $errorID = $dsa->executeIgnoreErrors($query, $result, $errors);
        $this->assertEqual($errorID, 1146);
        $now = new Date('2004-06-06');
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_raw_ad_impression']}_" . $now->format('%Y%m%d');
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 6);
        $now = new Date('2004-06-05');
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_raw_ad_request']}_" . $now->format('%Y%m%d');
        $errors = array(1146);   // Permit the table does not exist error
        $errorID = $dsa->executeIgnoreErrors($query, $result, $errors);
        $this->assertEqual($errorID, 1146);
        $now = new Date('2004-06-06');
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_raw_ad_request']}_" . $now->format('%Y%m%d');
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 6);
        // Disable the tracker
        $conf['modules']['Tracker'] = false;
        // Drop and re-create the raw tables
        $now = new Date('2004-06-06');
        $dsa->tables->dropTable($conf['table']['data_raw_ad_click'] . '_' . $now->format('%Y%m%d'));
        $dsa->tables->dropTable($conf['table']['data_raw_ad_impression'] . '_' . $now->format('%Y%m%d'));
        $dsa->tables->dropTable($conf['table']['data_raw_ad_request'] . '_' . $now->format('%Y%m%d'));
        $now = new Date('2004-06-05');
        $dsa->tables->createTable('data_raw_ad_click', $now);
        $dsa->tables->createTable('data_raw_ad_impression', $now);
        $dsa->tables->createTable('data_raw_ad_request', $now);
        $now = new Date('2004-06-06');
        $dsa->tables->createTable('data_raw_ad_click', $now);
        $dsa->tables->createTable('data_raw_ad_impression', $now);
        $dsa->tables->createTable('data_raw_ad_request', $now);
        // Re-insert the test data
        $dsa->execute(SPLIT_DELETE_OLD_DATA_AD_CLICKS_ONE, $result);
        $dsa->execute(SPLIT_DELETE_OLD_DATA_AD_CLICKS_TWO, $result);
        $dsa->execute(SPLIT_DELETE_OLD_DATA_AD_IMPRESSIONS_ONE, $result);
        $dsa->execute(SPLIT_DELETE_OLD_DATA_AD_IMPRESSIONS_TWO, $result);
        $dsa->execute(SPLIT_DELETE_OLD_DATA_AD_REQUESTS_ONE, $result);
        $dsa->execute(SPLIT_DELETE_OLD_DATA_AD_REQUESTS_TWO, $result);
        // Test
        $summarisedTo = new Date('2004-06-06 17:59:59');
        $dsa->deleteOldData($summarisedTo);
        $now = new Date('2004-06-05');
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_raw_ad_click']}_" . $now->format('%Y%m%d');
        $errors = array(1146);   // Permit the table does not exist error
        $errorID = $dsa->executeIgnoreErrors($query, $result, $errors);
        $this->assertEqual($errorID, 1146);
        $now = new Date('2004-06-06');
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_raw_ad_click']}_" . $now->format('%Y%m%d');
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 6);
        $now = new Date('2004-06-05');
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_raw_ad_impression']}_" . $now->format('%Y%m%d');
        $errors = array(1146);   // Permit the table does not exist error
        $errorID = $dsa->executeIgnoreErrors($query, $result, $errors);
        $this->assertEqual($errorID, 1146);
        $now = new Date('2004-06-06');
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_raw_ad_impression']}_" . $now->format('%Y%m%d');
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 6);
        $now = new Date('2004-06-05');
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_raw_ad_request']}_" . $now->format('%Y%m%d');
        $errors = array(1146);   // Permit the table does not exist error
        $errorID = $dsa->executeIgnoreErrors($query, $result, $errors);
        $this->assertEqual($errorID, 1146);
        $now = new Date('2004-06-06');
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_raw_ad_request']}_" . $now->format('%Y%m%d');
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 6);
        // Drop and re-create the raw tables
        $now = new Date('2004-06-06');
        $dsa->tables->dropTable($conf['table']['data_raw_ad_click'] . '_' . $now->format('%Y%m%d'));
        $dsa->tables->dropTable($conf['table']['data_raw_ad_impression'] . '_' . $now->format('%Y%m%d'));
        $dsa->tables->dropTable($conf['table']['data_raw_ad_request'] . '_' . $now->format('%Y%m%d'));
        $now = new Date('2004-06-05');
        $dsa->tables->createTable('data_raw_ad_click', $now);
        $dsa->tables->createTable('data_raw_ad_impression', $now);
        $dsa->tables->createTable('data_raw_ad_request', $now);
        $now = new Date('2004-06-06');
        $dsa->tables->createTable('data_raw_ad_click', $now);
        $dsa->tables->createTable('data_raw_ad_impression', $now);
        $dsa->tables->createTable('data_raw_ad_request', $now);
        // Re-insert the test data
        $dsa->execute(SPLIT_DELETE_OLD_DATA_AD_CLICKS_ONE, $result);
        $dsa->execute(SPLIT_DELETE_OLD_DATA_AD_CLICKS_TWO, $result);
        $dsa->execute(SPLIT_DELETE_OLD_DATA_AD_IMPRESSIONS_ONE, $result);
        $dsa->execute(SPLIT_DELETE_OLD_DATA_AD_IMPRESSIONS_TWO, $result);
        $dsa->execute(SPLIT_DELETE_OLD_DATA_AD_REQUESTS_ONE, $result);
        $dsa->execute(SPLIT_DELETE_OLD_DATA_AD_REQUESTS_TWO, $result);
        // Test
        $summarisedTo = new Date('2004-06-06 18:00:00');
        $dsa->deleteOldData($summarisedTo);
        $now = new Date('2004-06-05');
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_raw_ad_click']}_" . $now->format('%Y%m%d');
        $errors = array(1146);   // Permit the table does not exist error
        $errorID = $dsa->executeIgnoreErrors($query, $result, $errors);
        $this->assertEqual($errorID, 1146);
        $now = new Date('2004-06-06');
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_raw_ad_click']}_" . $now->format('%Y%m%d');
        $errors = array(1146);   // Permit the table does not exist error
        $errorID = $dsa->executeIgnoreErrors($query, $result, $errors);
        $this->assertEqual($errorID, 1146);
        $now = new Date('2004-06-05');
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_raw_ad_impression']}_" . $now->format('%Y%m%d');
        $errors = array(1146);   // Permit the table does not exist error
        $errorID = $dsa->executeIgnoreErrors($query, $result, $errors);
        $this->assertEqual($errorID, 1146);
        $now = new Date('2004-06-06');
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_raw_ad_click']}_" . $now->format('%Y%m%d');
        $errors = array(1146);   // Permit the table does not exist error
        $errorID = $dsa->executeIgnoreErrors($query, $result, $errors);
        $this->assertEqual($errorID, 1146);
        $now = new Date('2004-06-05');
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_raw_ad_request']}_" . $now->format('%Y%m%d');
        $errors = array(1146);   // Permit the table does not exist error
        $errorID = $dsa->executeIgnoreErrors($query, $result, $errors);
        $this->assertEqual($errorID, 1146);
        $now = new Date('2004-06-06');
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_raw_ad_click']}_" . $now->format('%Y%m%d');
        $errors = array(1146);   // Permit the table does not exist error
        $errorID = $dsa->executeIgnoreErrors($query, $result, $errors);
        $this->assertEqual($errorID, 1146);
        // Set a compact_stats_grace window
        $conf['maintenance']['compact_stats_grace'] = 3600;
        // Enable the tracker
        $conf['modules']['Tracker'] = true;
        // Create the required tables
        $now = new Date('2004-06-05');
        $dsa->tables->createTable('data_raw_ad_click', $now);
        $dsa->tables->createTable('data_raw_ad_impression', $now);
        $dsa->tables->createTable('data_raw_ad_request', $now);
        $now = new Date('2004-06-06');
        $dsa->tables->createTable('data_raw_ad_click', $now);
        $dsa->tables->createTable('data_raw_ad_impression', $now);
        $dsa->tables->createTable('data_raw_ad_request', $now);
        // Insert the test data
        $dsa->execute(SPLIT_DELETE_OLD_DATA_AD_CLICKS_ONE, $result);
        $dsa->execute(SPLIT_DELETE_OLD_DATA_AD_CLICKS_TWO, $result);
        $dsa->execute(SPLIT_DELETE_OLD_DATA_AD_IMPRESSIONS_ONE, $result);
        $dsa->execute(SPLIT_DELETE_OLD_DATA_AD_IMPRESSIONS_TWO, $result);
        $dsa->execute(SPLIT_DELETE_OLD_DATA_AD_REQUESTS_ONE, $result);
        $dsa->execute(SPLIT_DELETE_OLD_DATA_AD_REQUESTS_TWO, $result);
        // Test
        $summarisedTo = new Date('2004-06-06 17:59:59');
        $dsa->deleteOldData($summarisedTo);
        $now = new Date('2004-06-05');
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_raw_ad_click']}_" . $now->format('%Y%m%d');
        $errors = array(1146);   // Permit the table does not exist error
        $errorID = $dsa->executeIgnoreErrors($query, $result, $errors);
        $this->assertEqual($errorID, 1146);
        $now = new Date('2004-06-06');
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_raw_ad_click']}_" . $now->format('%Y%m%d');
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 6);
        $now = new Date('2004-06-05');
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_raw_ad_impression']}_" . $now->format('%Y%m%d');
        $errors = array(1146);   // Permit the table does not exist error
        $errorID = $dsa->executeIgnoreErrors($query, $result, $errors);
        $this->assertEqual($errorID, 1146);
        $now = new Date('2004-06-06');
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_raw_ad_impression']}_" . $now->format('%Y%m%d');
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 6);
        $now = new Date('2004-06-05');
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_raw_ad_request']}_" . $now->format('%Y%m%d');
        $errors = array(1146);   // Permit the table does not exist error
        $errorID = $dsa->executeIgnoreErrors($query, $result, $errors);
        $this->assertEqual($errorID, 1146);
        $now = new Date('2004-06-06');
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_raw_ad_request']}_" . $now->format('%Y%m%d');
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 6);
        // Disable the tracker
        $conf['modules']['Tracker'] = false;
        // Drop and re-create the raw tables
        $now = new Date('2004-06-06');
        $dsa->tables->dropTable($conf['table']['data_raw_ad_click'] . '_' . $now->format('%Y%m%d'));
        $dsa->tables->dropTable($conf['table']['data_raw_ad_impression'] . '_' . $now->format('%Y%m%d'));
        $dsa->tables->dropTable($conf['table']['data_raw_ad_request'] . '_' . $now->format('%Y%m%d'));
        $now = new Date('2004-06-05');
        $dsa->tables->createTable('data_raw_ad_click', $now);
        $dsa->tables->createTable('data_raw_ad_impression', $now);
        $dsa->tables->createTable('data_raw_ad_request', $now);
        $now = new Date('2004-06-06');
        $dsa->tables->createTable('data_raw_ad_click', $now);
        $dsa->tables->createTable('data_raw_ad_impression', $now);
        $dsa->tables->createTable('data_raw_ad_request', $now);
        // Re-insert the test data
        $dsa->execute(SPLIT_DELETE_OLD_DATA_AD_CLICKS_ONE, $result);
        $dsa->execute(SPLIT_DELETE_OLD_DATA_AD_CLICKS_TWO, $result);
        $dsa->execute(SPLIT_DELETE_OLD_DATA_AD_IMPRESSIONS_ONE, $result);
        $dsa->execute(SPLIT_DELETE_OLD_DATA_AD_IMPRESSIONS_TWO, $result);
        $dsa->execute(SPLIT_DELETE_OLD_DATA_AD_REQUESTS_ONE, $result);
        $dsa->execute(SPLIT_DELETE_OLD_DATA_AD_REQUESTS_TWO, $result);
        // Test
        $summarisedTo = new Date('2004-06-06 17:59:59');
        $dsa->deleteOldData($summarisedTo);
        $now = new Date('2004-06-05');
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_raw_ad_click']}_" . $now->format('%Y%m%d');
        $errors = array(1146);   // Permit the table does not exist error
        $errorID = $dsa->executeIgnoreErrors($query, $result, $errors);
        $this->assertEqual($errorID, 1146);
        $now = new Date('2004-06-06');
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_raw_ad_click']}_" . $now->format('%Y%m%d');
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 6);
        $now = new Date('2004-06-05');
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_raw_ad_impression']}_" . $now->format('%Y%m%d');
        $errors = array(1146);   // Permit the table does not exist error
        $errorID = $dsa->executeIgnoreErrors($query, $result, $errors);
        $this->assertEqual($errorID, 1146);
        $now = new Date('2004-06-06');
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_raw_ad_impression']}_" . $now->format('%Y%m%d');
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 6);
        $now = new Date('2004-06-05');
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_raw_ad_request']}_" . $now->format('%Y%m%d');
        $errors = array(1146);   // Permit the table does not exist error
        $errorID = $dsa->executeIgnoreErrors($query, $result, $errors);
        $this->assertEqual($errorID, 1146);
        $now = new Date('2004-06-06');
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_raw_ad_request']}_" . $now->format('%Y%m%d');
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 6);
        // Drop and re-create the raw tables
        $now = new Date('2004-06-06');
        $dsa->tables->dropTable($conf['table']['data_raw_ad_click'] . '_' . $now->format('%Y%m%d'));
        $dsa->tables->dropTable($conf['table']['data_raw_ad_impression'] . '_' . $now->format('%Y%m%d'));
        $dsa->tables->dropTable($conf['table']['data_raw_ad_request'] . '_' . $now->format('%Y%m%d'));
        $now = new Date('2004-06-05');
        $dsa->tables->createTable('data_raw_ad_click', $now);
        $dsa->tables->createTable('data_raw_ad_impression', $now);
        $dsa->tables->createTable('data_raw_ad_request', $now);
        $now = new Date('2004-06-06');
        $dsa->tables->createTable('data_raw_ad_click', $now);
        $dsa->tables->createTable('data_raw_ad_impression', $now);
        $dsa->tables->createTable('data_raw_ad_request', $now);
        // Re-insert the test data
        $dsa->execute(SPLIT_DELETE_OLD_DATA_AD_CLICKS_ONE, $result);
        $dsa->execute(SPLIT_DELETE_OLD_DATA_AD_CLICKS_TWO, $result);
        $dsa->execute(SPLIT_DELETE_OLD_DATA_AD_IMPRESSIONS_ONE, $result);
        $dsa->execute(SPLIT_DELETE_OLD_DATA_AD_IMPRESSIONS_TWO, $result);
        $dsa->execute(SPLIT_DELETE_OLD_DATA_AD_REQUESTS_ONE, $result);
        $dsa->execute(SPLIT_DELETE_OLD_DATA_AD_REQUESTS_TWO, $result);
        // Test
        $summarisedTo = new Date('2004-06-06 18:00:00');
        $dsa->deleteOldData($summarisedTo);
        $now = new Date('2004-06-05');
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_raw_ad_click']}_" . $now->format('%Y%m%d');
        $errors = array(1146);   // Permit the table does not exist error
        $errorID = $dsa->executeIgnoreErrors($query, $result, $errors);
        $this->assertEqual($errorID, 1146);
        $now = new Date('2004-06-06');
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_raw_ad_click']}_" . $now->format('%Y%m%d');
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 6);
        $now = new Date('2004-06-05');
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_raw_ad_impression']}_" . $now->format('%Y%m%d');
        $errors = array(1146);   // Permit the table does not exist error
        $errorID = $dsa->executeIgnoreErrors($query, $result, $errors);
        $this->assertEqual($errorID, 1146);
        $now = new Date('2004-06-06');
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_raw_ad_impression']}_" . $now->format('%Y%m%d');
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 6);
        $now = new Date('2004-06-05');
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_raw_ad_request']}_" . $now->format('%Y%m%d');
        $errors = array(1146);   // Permit the table does not exist error
        $errorID = $dsa->executeIgnoreErrors($query, $result, $errors);
        $this->assertEqual($errorID, 1146);
        $now = new Date('2004-06-06');
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['data_raw_ad_request']}_" . $now->format('%Y%m%d');
        $dsa->execute($query, $result);
        $row = mysql_fetch_array($result);
        $this->assertEqual($row['number'], 6);
        // Drop the tables
        $dsa->tables->dropTable($conf['table']['campaigns_trackers']);
        $now = new Date('2004-06-06');
        $dsa->tables->dropTable($conf['table']['data_raw_ad_click'] . '_' . $now->format('%Y%m%d'));
        $dsa->tables->dropTable($conf['table']['data_raw_ad_impression'] . '_' . $now->format('%Y%m%d'));
        $dsa->tables->dropTable($conf['table']['data_raw_ad_request'] . '_' . $now->format('%Y%m%d'));
    }
    
}

?>
