<?php

/*
+---------------------------------------------------------------------------+
| Max Media Manager v0.2                                                    |
| =================                                                         |
|                                                                           |
| Copyright (c) 2003-2005 Awarez Ltd.                                       |
| For contact details, see: http://www.awarez.net/                          |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: TestOfGeoIP.php 1242 2005-01-18 11:10:09Z andrew $
*/

/**
 * @package    MaxDelivery
 * @subpackage TestSuite
 * @author     Andrew Hill <andrew@awarez.net>
 */

require_once MAX_PATH . '/libraries/geotargeting/geoip.inc.php';

/**
 * A class for testing the geoipGetInfo function. Will only test
 * all database types if the databases are available - contact
 * MaxMind LLC (http://maxmind.com/).
 *
 * @TODO Needs a copy of the Netspeed database to test.
 */
class Delivery_TestOfGeoIP extends UnitTestCase
{
    
    /**
     * The constructor method.
     */
    function Delivery_TestOfGeoIP()
    {        
        $this->UnitTestCase();
    }
    
    /**
     * Test the geoipGetInfo function.
     */
    function testGeoipGetInfo()
    {
        $config =& $GLOBALS['phpAds_config'];
        // Set a fake, known IP address
        $ip = '24.24.24.24';
        // Test with no additional MaxMind GeoIP databases
        $config['geotracking_geoip_country_location'] = '';
        $config['geotracking_geoip_region_location'] = '';
        $config['geotracking_geoip_city_location'] = '';
        $config['geotracking_geoip_area_location'] = '';
        $config['geotracking_geoip_dma_location'] = '';
        $config['geotracking_geoip_org_location'] = '';
        $config['geotracking_geoip_isp_location'] = '';
        $config['geotracking_geoip_netspeed_location'] = '';
        $result = array();
        geoipGetInfo($ip, $result);
        $this->assertEqual($result['country_code'], 'US');
        $this->assertEqual($result['country_name'], 'United States');
        $this->assertNull($result['region']);
        $this->assertNull($result['city']);
        $this->assertNull($result['postal_code']);
        $this->assertNull($result['latitude']);
        $this->assertNull($result['longitude']);
        $this->assertNull($result['dma_code']);
        $this->assertNull($result['area_code']);
        $this->assertNull($result['organisation']);
        $this->assertNull($result['isp']);
        $this->assertNull($result['netspeed']);
        // Test with a supplied GeoIP Country database
        $config['geotracking_geoip_country_location'] =
            MAX_PATH . '/tests/delivery/libraries/geotargeting/FreeGeoIPCountry.dat';
        $config['geotracking_geoip_region_location'] = '';
        $config['geotracking_geoip_city_location'] = '';
        $config['geotracking_geoip_area_location'] = '';
        $config['geotracking_geoip_dma_location'] = '';
        $config['geotracking_geoip_org_location'] = '';
        $config['geotracking_geoip_isp_location'] = '';
        $config['geotracking_geoip_netspeed_location'] = '';
        $result = array();
        geoipGetInfo($ip, $result);
        $this->assertEqual($result['country_code'], 'US');
        $this->assertEqual($result['country_name'], 'United States');
        $this->assertNull($result['region']);
        $this->assertNull($result['city']);
        $this->assertNull($result['postal_code']);
        $this->assertNull($result['latitude']);
        $this->assertNull($result['longitude']);
        $this->assertNull($result['dma_code']);
        $this->assertNull($result['area_code']);
        $this->assertNull($result['organisation']);
        $this->assertNull($result['isp']);
        $this->assertNull($result['netspeed']);
        // Test with a supplied GeoIP Region database
        $regionFile = MAX_PATH . '/tests/delivery/libraries/geotargeting/FakeGeoIPRegion.dat';
        if (file_exists($regionFile)) {
            $config['geotracking_geoip_country_location'] = '';
            $config['geotracking_geoip_region_location'] = $regionFile;
            $config['geotracking_geoip_city_location'] = '';
            $config['geotracking_geoip_area_location'] = '';
            $config['geotracking_geoip_dma_location'] = '';
            $config['geotracking_geoip_org_location'] = '';
            $config['geotracking_geoip_isp_location'] = '';
            $config['geotracking_geoip_netspeed_location'] = '';
            $result = array();
            geoipGetInfo($ip, $result);
            $this->assertEqual($result['country_code'], 'US');
            $this->assertEqual($result['country_name'], 'United States');
            $this->assertEqual($result['region'], 'VA');
            $this->assertNull($result['city']);
            $this->assertNull($result['postal_code']);
            $this->assertNull($result['latitude']);
            $this->assertNull($result['longitude']);
            $this->assertNull($result['dma_code']);
            $this->assertNull($result['area_code']);
            $this->assertNull($result['organisation']);
            $this->assertNull($result['isp']);
            $this->assertNull($result['netspeed']);
        }
        // Test with a supplied GeoIP City database
        $cityFile = MAX_PATH . '/tests/delivery/libraries/geotargeting/FakeGeoIPCity.dat';
        if (file_exists($cityFile)) {
            $config['geotracking_geoip_country_location'] = '';
            $config['geotracking_geoip_region_location'] = '';
            $config['geotracking_geoip_city_location'] = $cityFile;
            $config['geotracking_geoip_area_location'] = '';
            $config['geotracking_geoip_dma_location'] = '';
            $config['geotracking_geoip_org_location'] = '';
            $config['geotracking_geoip_isp_location'] = '';
            $config['geotracking_geoip_netspeed_location'] = '';
            $result = array();
            geoipGetInfo($ip, $result);
            $this->assertEqual($result['country_code'], 'US');
            $this->assertEqual($result['country_name'], 'United States');
            $this->assertEqual($result['region'], 'VA');
            $this->assertEqual($result['city'], 'Herndon');
            $this->assertEqual($result['postal_code'], '20171');
            $this->assertEqual($result['latitude'], '38.9252');
            $this->assertEqual($result['longitude'], '-77.3928');
            $this->assertEqual($result['dma_code'], 511);
            $this->assertEqual($result['area_code'], 703);
            $this->assertNull($result['organisation']);
            $this->assertNull($result['isp']);
            $this->assertNull($result['netspeed']);
        }
        // Test with a supplied GeoIP Area Code database
        $areaCodeFile = MAX_PATH . '/tests/delivery/libraries/geotargeting/FakeGeoIPCity.dat';
        if (file_exists($areaCodeFile)) {
            $config['geotracking_geoip_country_location'] = '';
            $config['geotracking_geoip_region_location'] = '';
            $config['geotracking_geoip_city_location'] = '';
            $config['geotracking_geoip_area_location'] = $areaCodeFile;
            $config['geotracking_geoip_dma_location'] = '';
            $config['geotracking_geoip_org_location'] = '';
            $config['geotracking_geoip_isp_location'] = '';
            $config['geotracking_geoip_netspeed_location'] = '';
            $result = array();
            geoipGetInfo($ip, $result);
            $this->assertEqual($result['country_code'], 'US');
            $this->assertEqual($result['country_name'], 'United States');
            $this->assertEqual($result['region'], 'VA');
            $this->assertNull($result['city']);
            $this->assertNull($result['postal_code']);
            $this->assertNull($result['latitude']);
            $this->assertNull($result['longitude']);
            $this->assertNull($result['dma_code']);
            $this->assertEqual($result['area_code'], 703);
            $this->assertNull($result['organisation']);
            $this->assertNull($result['isp']);
            $this->assertNull($result['netspeed']);
        }
        // Test with a supplied GeoIP DMA Code database
        $dmaCodeFile = MAX_PATH . '/tests/delivery/libraries/geotargeting/FakeGeoIPCity.dat';
        if (file_exists($dmaCodeFile)) {
            $config['geotracking_geoip_country_location'] = '';
            $config['geotracking_geoip_region_location'] = '';
            $config['geotracking_geoip_city_location'] = '';
            $config['geotracking_geoip_area_location'] = '';
            $config['geotracking_geoip_dma_location'] = $dmaCodeFile;
            $config['geotracking_geoip_org_location'] = '';
            $config['geotracking_geoip_isp_location'] = '';
            $config['geotracking_geoip_netspeed_location'] = '';
            $result = array();
            geoipGetInfo($ip, $result);
            $this->assertEqual($result['country_code'], 'US');
            $this->assertEqual($result['country_name'], 'United States');
            $this->assertEqual($result['region'], 'VA');
            $this->assertNull($result['city']);
            $this->assertNull($result['postal_code']);
            $this->assertNull($result['latitude']);
            $this->assertNull($result['longitude']);
            $this->assertEqual($result['dma_code'], 511);
            $this->assertNull($result['area_code']);
            $this->assertNull($result['organisation']);
            $this->assertNull($result['isp']);
            $this->assertNull($result['netspeed']);
        }
        // Test with a supplied GeoIP Organisation database
        $orgFile = MAX_PATH . '/tests/delivery/libraries/geotargeting/FakeGeoIPOrg.dat';
        if (file_exists($orgFile)) {
            $config['geotracking_geoip_country_location'] = '';
            $config['geotracking_geoip_region_location'] = '';
            $config['geotracking_geoip_city_location'] = '';
            $config['geotracking_geoip_area_location'] = '';
            $config['geotracking_geoip_dma_location'] = '';
            $config['geotracking_geoip_org_location'] = $orgFile;
            $config['geotracking_geoip_isp_location'] = '';
            $config['geotracking_geoip_netspeed_location'] = '';
            $result = array();
            geoipGetInfo($ip, $result);
            $this->assertEqual($result['country_code'], 'US');
            $this->assertEqual($result['country_name'], 'United States');
            $this->assertNull($result['region']);
            $this->assertNull($result['city']);
            $this->assertNull($result['postal_code']);
            $this->assertNull($result['latitude']);
            $this->assertNull($result['longitude']);
            $this->assertNull($result['dma_code']);
            $this->assertNull($result['area_code']);
            $this->assertEqual($result['organisation'], 'Road Runner');
            $this->assertNull($result['isp']);
            $this->assertNull($result['netspeed']);
        }
        // Test with a supplied GeoIP ISP database
        $ispFile = MAX_PATH . '/tests/delivery/libraries/geotargeting/FakeGeoIPOrg.dat';
        if (file_exists($ispFile)) {
            $config['geotracking_geoip_country_location'] = '';
            $config['geotracking_geoip_region_location'] = '';
            $config['geotracking_geoip_city_location'] = '';
            $config['geotracking_geoip_area_location'] = '';
            $config['geotracking_geoip_dma_location'] = '';
            $config['geotracking_geoip_org_location'] = '';
            $config['geotracking_geoip_isp_location'] = $ispFile;
            $config['geotracking_geoip_netspeed_location'] = '';
            $result = array();
            geoipGetInfo($ip, $result);
            $this->assertEqual($result['country_code'], 'US');
            $this->assertEqual($result['country_name'], 'United States');
            $this->assertNull($result['region']);
            $this->assertNull($result['city']);
            $this->assertNull($result['postal_code']);
            $this->assertNull($result['latitude']);
            $this->assertNull($result['longitude']);
            $this->assertNull($result['dma_code']);
            $this->assertNull($result['area_code']);
            $this->assertNull($result['organisation']);
            $this->assertEqual($result['isp'], 'Road Runner');
            $this->assertNull($result['netspeed']);
        }
    }
    
}

?>
